@@ -52,6 +52,7 @@
 #include "prmem.h"
 #include "nsCRT.h"
 
+#include "nsXPCOM.h"
 #include "nsISupportsPrimitives.h"
 #include "nsICharsetDetector.h"
 
@@ -77,7 +78,7 @@ NS_IMPL_THREADSAFE_ISUPPORTS2(nsCharsetConverterManager,
 nsCharsetConverterManager::nsCharsetConverterManager() 
 :mDataBundle(NULL), mTitleBundle(NULL)
 {
-  NS_INIT_REFCNT();
+  NS_INIT_ISUPPORTS();
 }
 
 nsCharsetConverterManager::~nsCharsetConverterManager() 
@@ -297,14 +298,14 @@ nsCharsetConverterManager::GetList(const nsACString& aCategory,
     if (NS_FAILED(enumerator->GetNext(getter_AddRefs(supports))))
       continue;
     
-    nsCOMPtr<nsISupportsString> supStr = do_QueryInterface(supports);
+    nsCOMPtr<nsISupportsCString> supStr = do_QueryInterface(supports);
     if (!supStr)
       continue;
 
     nsCAutoString fullName(aPrefix);
     
-    nsXPIDLCString name;
-    if (NS_FAILED(supStr->GetData(getter_Copies(name))))
+    nsCAutoString name;
+    if (NS_FAILED(supStr->GetData(name)))
       continue;
 
     fullName += name;
