@@ -72,6 +72,7 @@
 #include "nsReadableUtils.h"
 #include "nsUnicharUtils.h"
 #include "nsPrintfCString.h"
+#include "nsDummyLayoutRequest.h"
 
   #ifdef DEBUG
     //#define NOISY_DEBUG
@@ -248,10 +249,15 @@ class FrameManager;
   // The event queue owns the event and the FrameManager will delete
   // the event if it's going to go away.
 struct CantRenderReplacedElementEvent : public PLEvent {
-  CantRenderReplacedElementEvent(FrameManager* aFrameManager, nsIFrame* aFrame);
+  CantRenderReplacedElementEvent(FrameManager* aFrameManager, nsIFrame* aFrame, nsIPresShell* aPresShell);
+  ~CantRenderReplacedElementEvent();
+  nsresult AddLoadGroupRequest(nsIPresShell* aPresShell);
+  nsresult RemoveLoadGroupRequest();
 
   nsIFrame*  mFrame;                     // the frame that can't be rendered
   CantRenderReplacedElementEvent* mNext; // next event in the list
+  nsCOMPtr<nsIRequest> mDummyLayoutRequest; // load group request
+  nsWeakPtr mPresShell;                     // for removing load group request later
 };
 
 class FrameManager : public nsIFrameManager
@@ -333,8 +339,8 @@ public:
                                    PRInt32 aAttrNameSpaceID,
                                    nsIAtom* aAttribute,
                                    nsStyleChangeList& aChangeList,
-                                   PRInt32 aMinChange,
-                                   PRInt32& aTopLevelChange);
+                                   nsChangeHint aMinChange,
+                                   nsChangeHint& aTopLevelChange);
   NS_IMETHOD AttributeAffectsStyle(nsIAtom *aAttribute, nsIContent *aContent,
                                    PRBool &aAffects);
 
@@ -411,8 +417,8 @@ private:
                              PRInt32 aAttrNameSpaceID,
                              nsIAtom* aAttribute,
                              nsStyleChangeList& aChangeList, 
-                             PRInt32 aMinChange,
-                             PRInt32& aResultChange);
+                             nsChangeHint aMinChange,
+                             nsChangeHint& aResultChange);
 
   nsresult RevokePostedEvents();
   CantRenderReplacedElementEvent** FindPostedEventFor(nsIFrame* aFrame);
@@ -444,7 +450,7 @@ NS_NewFrameManager(nsIFrameManager** aInstancePtrResult)
 
 FrameManager::FrameManager()
 {
-  NS_INIT_REFCNT();
+  NS_INIT_ISUPPORTS();
 }
 
 FrameManager::~FrameManager()
@@ -1182,12 +1188,73 @@ FrameManager::DestroyPLEvent(CantRenderReplacedElementEvent* aEvent)
 }
 
 CantRenderReplacedElementEvent::CantRenderReplacedElementEvent(FrameManager* aFrameManager,
-                                                               nsIFrame*     aFrame)
+                                                               nsIFrame*     aFrame,
+                                                               nsIPresShell* aPresShell)
 {
   PL_InitEvent(this, aFrameManager,
                (PLHandleEventProc)&FrameManager::HandlePLEvent,
                (PLDestroyEventProc)&FrameManager::DestroyPLEvent);
   mFrame = aFrame;
+  
+  nsIAtom*  frameType;
+  aFrame->GetFrameType(&frameType);
+  if (nsLayoutAtoms::objectFrame == frameType) {
+    AddLoadGroupRequest(aPresShell);
+  }
+}
+
+CantRenderReplacedElementEvent::~CantRenderReplacedElementEvent()
+{
+  RemoveLoadGroupRequest();
+}
+
+// Add a load group request in order to delay the onLoad handler when we have
+// pending replacements
+nsresult CantRenderReplacedElementEvent::AddLoadGroupRequest(nsIPresShell* aPresShell)
+{
+  nsCOMPtr<nsIDocument> doc;
+  aPresShell->GetDocument(getter_AddRefs(doc));
+  if (!doc) return NS_ERROR_FAILURE;
+
+  nsresult rv = nsDummyLayoutRequest::Create(getter_AddRefs(mDummyLayoutRequest), aPresShell);
+  if (NS_FAILED(rv)) return rv;
+  if (!mDummyLayoutRequest) return NS_ERROR_FAILURE;
+
+  nsCOMPtr<nsILoadGroup> loadGroup;
+  doc->GetDocumentLoadGroup(getter_AddRefs(loadGroup));
+  if (!loadGroup) return NS_ERROR_FAILURE;
+  
+  rv = mDummyLayoutRequest->SetLoadGroup(loadGroup);
+  if (NS_FAILED(rv)) return rv;
+  
+  mPresShell = getter_AddRefs(NS_GetWeakReference(aPresShell));
+
+  return loadGroup->AddRequest(mDummyLayoutRequest, nsnull);
+}
+
+// Remove the load group request added above
+nsresult CantRenderReplacedElementEvent::RemoveLoadGroupRequest()
+{
+  nsresult rv = NS_OK;
+
+  if (mDummyLayoutRequest) {
+    nsCOMPtr<nsIRequest> request = mDummyLayoutRequest;
+    mDummyLayoutRequest = nsnull;
+
+    nsCOMPtr<nsIPresShell> presShell = do_QueryReferent(mPresShell);
+    if (!presShell) return NS_ERROR_FAILURE;
+    
+    nsCOMPtr<nsIDocument> doc;
+    presShell->GetDocument(getter_AddRefs(doc));
+    if (!doc) return NS_ERROR_FAILURE;;
+
+    nsCOMPtr<nsILoadGroup> loadGroup;
+    doc->GetDocumentLoadGroup(getter_AddRefs(loadGroup));
+    if (!loadGroup) return NS_ERROR_FAILURE;
+
+    rv = loadGroup->RemoveRequest(request, nsnull, NS_OK);
+  }
+  return rv;
 }
 
 NS_IMETHODIMP
@@ -1218,7 +1285,7 @@ FrameManager::CantRenderReplacedElement(nsIPresContext* aPresContext,
       CantRenderReplacedElementEvent* ev;
 
       // Create a new event
-      ev = new CantRenderReplacedElementEvent(this, aFrame);
+      ev = new CantRenderReplacedElementEvent(this, aFrame, mPresShell);
 
       // Add the event to our linked list of posted events
       ev->mNext = mPostedEvents;
@@ -1290,13 +1357,13 @@ VerifySameTree(nsIStyleContext* aContext1, nsIStyleContext* aContext2)
   nsCOMPtr<nsIStyleContext> top2 = aContext2;
   nsCOMPtr<nsIStyleContext> parent;
   for (;;) {
-    parent = dont_AddRef(top1->GetParent());
+    parent = top1->GetParent();
     if (!parent)
       break;
     top1 = parent;
   }
   for (;;) {
-    parent = dont_AddRef(top2->GetParent());
+    parent = top2->GetParent();
     if (!parent)
       break;
     top2 = parent;
@@ -1336,7 +1403,7 @@ VerifyContextParent(nsIPresContext* aPresContext, nsIFrame* aFrame,
   }
 
   NS_ASSERTION(aContext, "Failure to get required contexts");
-  nsIStyleContext*  actualParentContext = aContext->GetParent();
+  nsCOMPtr<nsIStyleContext> actualParentContext = aContext->GetParent();
 
   if (aParentContext) {
     if (aParentContext != actualParentContext) {
@@ -1363,7 +1430,6 @@ VerifyContextParent(nsIPresContext* aPresContext, nsIFrame* aFrame,
     }
   }
 
-  NS_IF_RELEASE(actualParentContext);
   NS_IF_RELEASE(aParentContext);
   NS_IF_RELEASE(aContext);
 }
@@ -1436,12 +1502,10 @@ FrameManager::DebugVerifyStyleTree(nsIPresContext* aPresContext, nsIFrame* aFram
 {
   NS_ENSURE_TRUE(mPresShell, NS_ERROR_NOT_AVAILABLE);
   if (aFrame) {
-    nsIStyleContext* context;
-    aFrame->GetStyleContext(&context);
-    nsIStyleContext* parentContext = context->GetParent();
+    nsCOMPtr<nsIStyleContext> context;
+    aFrame->GetStyleContext(getter_AddRefs(context));
+    nsCOMPtr<nsIStyleContext> parentContext = context->GetParent();
     VerifyStyleTree(aPresContext, aFrame, parentContext);
-    NS_IF_RELEASE(parentContext);
-    NS_RELEASE(context);
   }
   return NS_OK;
 }
@@ -1589,16 +1653,15 @@ HasAttributeContent(nsIStyleContext* aStyleContext,
   return result;
 }
 
-static PRInt32
+static nsChangeHint
 CaptureChange(nsIStyleContext* aOldContext, nsIStyleContext* aNewContext,
               nsIFrame* aFrame, nsIContent* aContent,
-              nsStyleChangeList& aChangeList, PRInt32 aMinChange)
+              nsStyleChangeList& aChangeList, nsChangeHint aMinChange)
 {
-  PRInt32 ourChange = NS_STYLE_HINT_NONE;
+  nsChangeHint ourChange = NS_STYLE_HINT_NONE;
   aOldContext->CalcStyleDifference(aNewContext, ourChange);
-  if (aMinChange < ourChange) {
+  if (NS_UpdateHint(aMinChange, ourChange)) {
     aChangeList.AppendChange(aFrame, aContent, ourChange);
-    aMinChange = ourChange;
   }
   return aMinChange;
 }
@@ -1610,8 +1673,8 @@ FrameManager::ReResolveStyleContext(nsIPresContext* aPresContext,
                                     PRInt32 aAttrNameSpaceID,
                                     nsIAtom* aAttribute,
                                     nsStyleChangeList& aChangeList, 
-                                    PRInt32 aMinChange,
-                                    PRInt32& aResultChange)
+                                    nsChangeHint aMinChange,
+                                    nsChangeHint& aResultChange)
 {
   // XXXldb get new context from prev-in-flow if possible, to avoid
   // duplication.  (Or should we just let |GetContext| handle that?)
@@ -1706,7 +1769,8 @@ FrameManager::ReResolveStyleContext(nsIPresContext* aPresContext,
 
       if (newContext != oldContext) {
         aMinChange = CaptureChange(oldContext, newContext, aFrame, content, aChangeList, aMinChange);
-        if (aMinChange < NS_STYLE_HINT_FRAMECHANGE) { // if frame gets regenerated, let it keep old context
+        if (!(aMinChange & (nsChangeHint_ReconstructFrame | nsChangeHint_ReconstructDoc))) {
+          // if frame gets regenerated, let it keep old context
           aFrame->SetStyleContext(aPresContext, newContext);
         }
         // if old context had image and new context does not have the same image, 
@@ -1722,7 +1786,10 @@ FrameManager::ReResolveStyleContext(nsIPresContext* aPresContext,
       }
       else {
         if (pseudoTag && pseudoTag != nsHTMLAtoms::mozNonElementPseudo &&
-            aAttribute && (aMinChange < NS_STYLE_HINT_REFLOW) &&
+            aAttribute &&
+            (!(aMinChange &
+               (nsChangeHint_ReflowFrame | nsChangeHint_ReconstructFrame
+                | nsChangeHint_ReconstructDoc))) &&
             HasAttributeContent(oldContext, aAttrNameSpaceID, aAttribute)) {
           aChangeList.AppendChange(aFrame, content, NS_STYLE_HINT_REFLOW);
         }
@@ -1754,11 +1821,12 @@ FrameManager::ReResolveStyleContext(nsIPresContext* aPresContext,
             if (oldExtraContext != newExtraContext) {
               aMinChange = CaptureChange(oldExtraContext, newExtraContext, aFrame, 
                                          content, aChangeList, aMinChange);
-              if (aMinChange < NS_STYLE_HINT_FRAMECHANGE) {
+              if (!(aMinChange & (nsChangeHint_ReconstructFrame | nsChangeHint_ReconstructDoc))) {
                 aFrame->SetAdditionalStyleContext(contextIndex, newExtraContext);
               }
             }
             else {
+#if 0
               // XXXldb |oldContext| is null by this point, so this will
               // never do anything.
               if (pseudoTag && pseudoTag != nsHTMLAtoms::mozNonElementPseudo &&
@@ -1766,6 +1834,7 @@ FrameManager::ReResolveStyleContext(nsIPresContext* aPresContext,
                   HasAttributeContent(oldContext, aAttrNameSpaceID, aAttribute)) {
                 aChangeList.AppendChange(aFrame, content, NS_STYLE_HINT_REFLOW);
               }
+#endif
             }
             NS_RELEASE(newExtraContext);
           }
@@ -1821,7 +1890,7 @@ FrameManager::ReResolveStyleContext(nsIPresContext* aPresContext,
 
     aResultChange = aMinChange;
 
-    if (aMinChange < NS_STYLE_HINT_FRAMECHANGE) {
+    if (!(aMinChange & (nsChangeHint_ReconstructFrame | nsChangeHint_ReconstructDoc))) {
       // There is no need to waste time crawling into a frame's children on a frame change.
       // The act of reconstructing frames will force new style contexts to be resolved on all
       // of this frame's descendants anyway, so we want to avoid wasting time processing
@@ -1830,7 +1899,7 @@ FrameManager::ReResolveStyleContext(nsIPresContext* aPresContext,
       // now do children
       PRInt32 listIndex = 0;
       nsIAtom* childList = nsnull;
-      PRInt32 childChange;
+      nsChangeHint childChange;
 
       do {
         nsIFrame* child = nsnull;
@@ -1892,12 +1961,13 @@ FrameManager::ComputeStyleChangeFor(nsIPresContext* aPresContext,
                                     PRInt32 aAttrNameSpaceID,
                                     nsIAtom* aAttribute,
                                     nsStyleChangeList& aChangeList,
-                                    PRInt32 aMinChange,
-                                    PRInt32& aTopLevelChange)
+                                    nsChangeHint aMinChange,
+                                    nsChangeHint& aTopLevelChange)
 {
   NS_ENSURE_TRUE(mPresShell, NS_ERROR_NOT_AVAILABLE);
   aTopLevelChange = NS_STYLE_HINT_NONE;
   nsIFrame* frame = aFrame;
+  nsIFrame* frame2 = aFrame;
 
 #ifdef DEBUG
   {
@@ -1907,32 +1977,49 @@ FrameManager::ComputeStyleChangeFor(nsIPresContext* aPresContext,
   }
 #endif
 
+  // We want to start with this frame and walk all its next-in-flows,
+  // as well as all its special siblings and their next-in-flows,
+  // reresolving style on all the frames we encounter in this walk.
+  
   do {
-    PRInt32 frameChange;
-    ReResolveStyleContext(aPresContext, frame, nsnull,
-                          aAttrNameSpaceID, aAttribute,
-                          aChangeList, aMinChange, frameChange);
+    // Outer loop over special siblings
+    do {
+      // Inner loop over next-in-flows of the current frame
+      nsChangeHint frameChange;
+      ReResolveStyleContext(aPresContext, frame, nsnull,
+                            aAttrNameSpaceID, aAttribute,
+                            aChangeList, aMinChange, frameChange);
 #ifdef NS_DEBUG
-    VerifyStyleTree(aPresContext, frame, nsnull);
+      VerifyStyleTree(aPresContext, frame, nsnull);
 #endif
-    if (aTopLevelChange < frameChange) {
-      aTopLevelChange = frameChange;
-    }
+      NS_UpdateHint(aTopLevelChange, frameChange);
 
-    if (aTopLevelChange >= NS_STYLE_HINT_FRAMECHANGE) {
-      // If it's going to cause a framechange, then don't bother with
-      // the continutaions since they'll be clobbered by the frame
-      // reconstruct anyway.
+      if (aTopLevelChange & (nsChangeHint_ReconstructDoc | nsChangeHint_ReconstructFrame)) {
+        // If it's going to cause a framechange, then don't bother
+        // with the continuations or special siblings since they'll be
+        // clobbered by the frame reconstruct anyway.
 #ifdef NS_DEBUG
-      nsIFrame* prevInFlow;
-      frame->GetPrevInFlow(&prevInFlow);
-      NS_ASSERTION(!prevInFlow, "continuing frame had more severe impact than first-in-flow");
+        nsIFrame* prevInFlow;
+        frame->GetPrevInFlow(&prevInFlow);
+        NS_ASSERTION(!prevInFlow, "continuing frame had more severe impact than first-in-flow");
 #endif
-      break;
-    }
+        return NS_OK;
+      }
 
-    frame->GetNextInFlow(&frame);
-  } while (frame);
+      frame->GetNextInFlow(&frame);
+    } while (frame);
+
+    // Might we have special siblings?
+    nsFrameState frame2state;
+    frame2->GetFrameState(&frame2state);
+    if (! (frame2state & NS_FRAME_IS_SPECIAL)) {
+      // nothing more to do here
+      return NS_OK;
+    }
+    
+    GetFrameProperty(frame2, nsLayoutAtoms::IBSplitSpecialSibling, 0, (void**)&frame2);
+    frame = frame2;
+  } while (frame2);
   return NS_OK;
 }
 
@@ -1944,6 +2031,13 @@ FrameManager::AttributeAffectsStyle(nsIAtom *aAttribute, nsIContent *aContent,
   nsresult rv = NS_OK;
   NS_ENSURE_TRUE(mPresShell, NS_ERROR_NOT_AVAILABLE);
 
+  if (aAttribute == nsHTMLAtoms::style) {
+    // Perhaps should check that it's XUL, SVG, (or HTML) namespace, but
+    // it doesn't really matter.
+    aAffects = PR_TRUE;
+    return NS_OK;
+  }
+
   nsCOMPtr<nsIXMLContent> xml(do_QueryInterface(aContent));
   if (xml) {
     rv = mStyleSet->AttributeAffectsStyle(aAttribute, aContent, aAffects);
@@ -2172,32 +2266,25 @@ FrameManager::GenerateStateKey(nsIContent* aContent,
     return NS_OK;
   }
 
-  // If we have a dom element, add tag/type/name to hash key
-  // This is paranoia, but guarantees that we won't restore
-  // state to the wrong type of control.
-  nsCOMPtr<nsIAtom> tag;
-  if (aContent->IsContentOfType(nsIContent::eHTML_FORM_CONTROL)) {
-
-    aContent->GetTag(*getter_AddRefs(tag));
-    KeyAppendAtom(tag, aKey);
-
-    nsAutoString name;
-    aContent->GetAttr(kNameSpaceID_None, nsHTMLAtoms::name, name);
-    KeyAppendString(name, aKey);
-  }
-
   // If we have a form control and can calculate form information, use
   // that as the key - it is more reliable than contentID.
   // Important to have a unique key, and tag/type/name may not be.
+  //
+  // If the control has a form, the format of the key is:
+  // type>IndOfFormInDoc>IndOfControlInForm>FormName>name
+  // else:
+  // type>IndOfControlInDoc>name
+  //
+  // XXX We don't need to use index if name is there
+  //
   nsCOMPtr<nsIFormControl> control(do_QueryInterface(aContent));
   PRBool generatedUniqueKey = PR_FALSE;
   if (control && mHTMLFormControls && mHTMLForms) {
 
-    if (tag == nsHTMLAtoms::input) {
-      PRInt32 type;
-      control->GetType(&type);
-      KeyAppendInt(type, aKey);
-    }
+    // Append the control type
+    PRInt32 type;
+    control->GetType(&type);
+    KeyAppendInt(type, aKey);
 
     // If in a form, add form name / index of form / index in form
     PRInt32 index = -1;
@@ -2210,10 +2297,7 @@ FrameManager::GenerateStateKey(nsIContent* aContent,
         return NS_OK;
       }
 
-      nsAutoString formName;
-      formElement->GetName(formName);
-      KeyAppendString(formName, aKey);
-
+      // Append the index of the form in the document
       nsCOMPtr<nsIContent> formContent(do_QueryInterface(formElement));
       mHTMLForms->IndexOf(formContent, index, PR_FALSE);
       if (index <= -1) {
@@ -2235,6 +2319,7 @@ FrameManager::GenerateStateKey(nsIContent* aContent,
       if (index > -1) {
         KeyAppendInt(index, aKey);
 
+        // Append the index of the control in the form
         nsCOMPtr<nsIForm> form(do_QueryInterface(formElement));
         form->IndexOfControl(control, &index);
         NS_ASSERTION(index > -1,
@@ -2246,6 +2331,11 @@ FrameManager::GenerateStateKey(nsIContent* aContent,
         }
       }
 
+      // Append the form name
+      nsAutoString formName;
+      formElement->GetName(formName);
+      KeyAppendString(formName, aKey);
+
     } else {
 
       // If not in a form, add index of control in document
@@ -2261,6 +2351,11 @@ FrameManager::GenerateStateKey(nsIContent* aContent,
         generatedUniqueKey = PR_TRUE;
       }
     }
+
+    // Append the control name
+    nsAutoString name;
+    aContent->GetAttr(kNameSpaceID_None, nsHTMLAtoms::name, name);
+    KeyAppendString(name, aKey);
   }
 
   if (!generatedUniqueKey) {
