@@ -69,6 +69,8 @@
 #include "nsIFrameManager.h"
 #include "nsGUIEvent.h"
 #include "nsIRootBox.h"
+#include "nsIDocShellTreeItem.h"
+#include "nsITimerInternal.h"
 #ifdef XP_WIN
 #include "nsISound.h"
 #endif
@@ -218,6 +220,7 @@ nsMenuPopupFrame::Init(nsIPresContext*  aPresContext,
   // Create a widget for ourselves.
   nsWidgetInitData widgetData;
   widgetData.mWindowType = eWindowType_popup;
+  widgetData.mContentType = nsIDocShellTreeItem::typeChrome;
   widgetData.mBorderStyle = eBorderStyle_default;
   widgetData.clipSiblings = PR_TRUE;
 
@@ -271,8 +274,8 @@ nsMenuPopupFrame::MarkStyleChange(nsBoxLayoutState& aState)
      return parent->RelayoutDirtyChild(aState, this);
   else {
     nsIPopupSetFrame* popupSet = GetPopupSetFrame(mPresContext);
-    nsCOMPtr<nsIBox> box(do_QueryInterface(popupSet));
-    if (box) {
+    nsIBox *box;
+    if (popupSet && NS_SUCCEEDED(CallQueryInterface(popupSet, &box))) {
       nsBoxLayoutState state(mPresContext);
       box->MarkDirtyChildren(state); // Mark the popupset as dirty.
     }
@@ -331,8 +334,8 @@ nsMenuPopupFrame::MarkDirty(nsBoxLayoutState& aState)
      return parent->RelayoutDirtyChild(aState, this);
   else {
     nsIPopupSetFrame* popupSet = GetPopupSetFrame(mPresContext);
-    nsCOMPtr<nsIBox> box(do_QueryInterface(popupSet));
-    if (box) {
+    nsIBox *box;
+    if (popupSet && NS_SUCCEEDED(CallQueryInterface(popupSet, &box))) {
       nsBoxLayoutState state(mPresContext);
       box->MarkDirtyChildren(state); // Mark the popupset as dirty.
     }
@@ -379,8 +382,8 @@ nsMenuPopupFrame::RelayoutDirtyChild(nsBoxLayoutState& aState, nsIBox* aChild)
       return parentBox->RelayoutDirtyChild(aState, this);
     else {
       nsIPopupSetFrame* popupSet = GetPopupSetFrame(mPresContext);
-      nsCOMPtr<nsIBox> box(do_QueryInterface(popupSet));
-      if (box) {
+      nsIBox *box;
+      if (popupSet && NS_SUCCEEDED(CallQueryInterface(popupSet, &box))) {
         nsBoxLayoutState state(mPresContext);
         box->MarkDirtyChildren(state); // Mark the popupset as dirty.
       }
@@ -606,7 +609,7 @@ nsMenuPopupFrame::AdjustClientXYForNestedDocuments ( nsIDOMXULDocument* inPopupD
   else
     inPopupDoc->GetPopupNode(getter_AddRefs(targetNode));
 
-  NS_WARN_IF_FALSE(targetNode, "no popup/tooltip node on document!");
+  //NS_WARN_IF_FALSE(targetNode, "no popup/tooltip node on document!");
   nsCOMPtr<nsIContent> targetAsContent ( do_QueryInterface(targetNode) );
   nsCOMPtr<nsIWidget> targetDocumentWidget;
   if ( targetAsContent ) {
@@ -617,19 +620,32 @@ nsMenuPopupFrame::AdjustClientXYForNestedDocuments ( nsIDOMXULDocument* inPopupD
       targetDocument->GetShellAt(0, getter_AddRefs(shell));
       nsCOMPtr<nsIViewManager> viewManagerTarget;
       if ( shell ) {
-        shell->GetViewManager(getter_AddRefs(viewManagerTarget));
-        if ( viewManagerTarget ) {
-          nsIView* rootViewTarget;
-          viewManagerTarget->GetRootView(rootViewTarget);
-          if ( rootViewTarget ) {
-            nscoord unusedX, unusedY;
-            rootViewTarget->GetOffsetFromWidget(&unusedX, &unusedY, *getter_AddRefs(targetDocumentWidget));
+        // We might be inside a popup widget. If so, we need to use that widget and
+        // not the root view's widget.
+        nsIFrame* targetFrame;
+        shell->GetPrimaryFrameFor(targetAsContent, &targetFrame);
+        nsIView* parentView = nsnull;
+        if (targetFrame) {
+          GetRootViewForPopup(mPresContext, targetFrame, &parentView);
+          GetWidgetForView(parentView, *getter_AddRefs(targetDocumentWidget));
+        }
+        if (!targetDocumentWidget) {
+          // We aren't inside a popup. This means we should use the root view's
+          // widget.
+          shell->GetViewManager(getter_AddRefs(viewManagerTarget));
+          if ( viewManagerTarget ) {
+            nsIView* rootViewTarget;
+            viewManagerTarget->GetRootView(rootViewTarget);
+            if ( rootViewTarget ) {
+              nscoord unusedX, unusedY;
+              rootViewTarget->GetOffsetFromWidget(&unusedX, &unusedY, *getter_AddRefs(targetDocumentWidget));
+            }
           }
         }
       }
     }
   }
-  NS_WARN_IF_FALSE(targetDocumentWidget, "ACK, BAD TARGET");
+  //NS_WARN_IF_FALSE(targetDocumentWidget, "ACK, BAD TARGET");
 
   // the offset we need is the difference between the upper left corner of the two widgets. Use
   // screen coordinates to find the global offset between them.
@@ -865,6 +881,7 @@ nsMenuPopupFrame::SyncViewWithFrame(nsIPresContext* aPresContext,
   //   if the canvas is scrolled so that part is off screen.
   nsIView* containingView = nsnull;
   nsPoint offset;
+  nsMargin margin;
   aFrame->GetOffsetFromView(aPresContext, offset, &containingView);
   if (!containingView)
     return NS_OK;
@@ -940,6 +957,19 @@ nsMenuPopupFrame::SyncViewWithFrame(nsIPresContext* aPresContext,
   nsCOMPtr<nsIScriptGlobalObject> scriptGlobalObject;
   document->GetScriptGlobalObject(getter_AddRefs(scriptGlobalObject));
   
+  nsCOMPtr<nsIContent> parentContent;
+  aFrame->GetContent(getter_AddRefs(parentContent));
+  nsCOMPtr<nsIAtom> tag;
+  mContent->GetTag(*getter_AddRefs(tag));
+  PRBool sizedToPopup = (tag != nsXULAtoms::tooltip)
+                        && (nsMenuFrame::IsSizedToPopup(parentContent, PR_FALSE));
+  
+  // If we stick to our parent's width, set it here before we move the
+  // window around, because moving is done with respect to the width...
+  if (sizedToPopup) {
+    mRect.width = parentRect.width;
+  }
+
   // |xpos| and |ypos| hold the x and y positions of where the popup will be moved to,
   // in _twips_, in the coordinate system of the _parent view_.
   PRInt32 xpos = 0, ypos = 0;
@@ -967,7 +997,6 @@ nsMenuPopupFrame::SyncViewWithFrame(nsIPresContext* aPresContext,
     // Add in the top and left margins
     const nsStyleMargin* smargin = 
       (const nsStyleMargin*)mStyleContext->GetStyleData(eStyleStruct_Margin);
-    nsMargin margin;
     smargin->GetMargin(margin);
     
     xpos += margin.left;
@@ -1052,13 +1081,6 @@ nsMenuPopupFrame::SyncViewWithFrame(nsIPresContext* aPresContext,
   PRInt32 screenViewLocX = NSIntPixelsToTwips(screenParentWidgetRect.x,p2t) + (xpos - parentPos.x);
   PRInt32 screenViewLocY = NSIntPixelsToTwips(screenParentWidgetRect.y,p2t) + (ypos - parentPos.y);
 
-  nsCOMPtr<nsIContent> parentContent;
-  aFrame->GetContent(getter_AddRefs(parentContent));
-  nsCOMPtr<nsIAtom> tag;
-  mContent->GetTag(*getter_AddRefs(tag));
-  PRBool sizedToPopup = (tag.get() != nsXULAtoms::tooltip)
-    && (nsMenuFrame::IsSizedToPopup(parentContent, PR_FALSE));
-
   if ( anchoredToParent ) {
     
     //
@@ -1093,27 +1115,16 @@ nsMenuPopupFrame::SyncViewWithFrame(nsIPresContext* aPresContext,
     screenParentFrameRect.x = NSIntPixelsToTwips(screenParentFrameRect.x, p2t);
     screenParentFrameRect.y = NSIntPixelsToTwips(screenParentFrameRect.y, p2t);
 
-    // If we stick to our parent's width, set it here before we move the
-    // window around, because moving is done with respect to the width...
-    if (sizedToPopup) {
-      mRect.width = screenParentFrameRect.width;
-    }
-
-    // Neither let it spill off the screen to the top...
+    // Don't let it spill off the screen to the top
     if (screenViewLocY < screenTopTwips) {
       PRInt32 moveDist = screenTopTwips - screenViewLocY;
       screenViewLocY = screenTopTwips;
       ypos += moveDist;
     }
-    // ... nor to the left.
-    if (screenViewLocX < screenLeftTwips) {
-      PRInt32 moveDist = screenLeftTwips - screenViewLocX;
-      screenViewLocX = screenLeftTwips;
-      xpos += moveDist;
-    }
     
     // if it doesn't fit on the screen, do our magic.
     if ( (screenViewLocX + mRect.width) > screenRightTwips ||
+           screenViewLocX < screenLeftTwips ||
           (screenViewLocY + mRect.height) > screenBottomTwips ) {
       
       // figure out which side of the parent has the most free space so we can move/resize
@@ -1139,6 +1150,13 @@ nsMenuPopupFrame::SyncViewWithFrame(nsIPresContext* aPresContext,
             moveDistX = screenViewLocX - screenLeftTwips;          
           screenViewLocX -= moveDistX;
           xpos -= moveDistX;
+        } else if (screenViewLocX < screenLeftTwips) {
+          // move right to be on screen, but don't let it go off the screen at the right
+          PRInt32 moveDistX = screenLeftTwips - screenViewLocX;
+          if ( (screenViewLocX + mRect.width + moveDistX) > screenRightTwips )
+            moveDistX = screenRightTwips - screenViewLocX - mRect.width;
+          screenViewLocX += moveDistX;
+          xpos += moveDistX;
         }
       }
       else {
@@ -1222,15 +1240,15 @@ nsMenuPopupFrame::SyncViewWithFrame(nsIPresContext* aPresContext,
 
     // ensure it is not even partially offscreen.
     if ( (screenViewLocX + mRect.width) > screenRightTwips ) {
-      // as a result of moving the popup, it might end up under the mouse. This
-      // would be bad as the subsequent mouse_up would trigger whatever
-      // unsuspecting item happens to be at that position. To get around this, make
-      // move it so the right edge is where the mouse is, as we're guaranteed
-      // that the mouse is on the screen!
-      xpos -= mRect.width;      
+      if (tag == nsXULAtoms::tooltip) {
+        //the tooltip is off the screen to the right - shift it to the left as much as needed
+        xpos -= (screenViewLocX + mRect.width) - screenRightTwips;
+      }
+      else        
+        xpos -= mRect.width;      
     }
     if ( (screenViewLocY + mRect.height) > screenBottomTwips )
-      ypos -= (screenViewLocY + mRect.height) - screenBottomTwips;
+      ypos -= (mRect.height + margin.top + margin.bottom);
       
   }  
 
@@ -1473,6 +1491,13 @@ void nsMenuPopupFrame::EnsureMenuItemIsVisible(nsIMenuFrame* aMenuItem)
 
 NS_IMETHODIMP nsMenuPopupFrame::SetCurrentMenuItem(nsIMenuFrame* aMenuItem)
 {
+  // When a context menu is open, the current menu is locked, and no change
+  // to the menu is allowed.
+  nsCOMPtr<nsIMenuParent> contextMenu;
+  GetContextMenu(getter_AddRefs(contextMenu));
+  if (contextMenu)
+    return NS_OK;
+
   if (mCurrentMenu == aMenuItem)
     return NS_OK;
   
@@ -1496,7 +1521,9 @@ NS_IMETHODIMP nsMenuPopupFrame::SetCurrentMenuItem(nsIMenuFrame* aMenuItem)
 
       // Kick off the timer.
       mCloseTimer = do_CreateInstance("@mozilla.org/timer;1");
-      mCloseTimer->Init(this, menuDelay, NS_PRIORITY_HIGHEST); 
+      nsCOMPtr<nsITimerInternal> ti = do_QueryInterface(mCloseTimer);
+      ti->SetIdle(PR_FALSE);
+      mCloseTimer->InitWithCallback(this, menuDelay, nsITimer::TYPE_ONE_SHOT); 
       mTimerMenu = mCurrentMenu;
     }
   }
@@ -1518,6 +1545,21 @@ nsMenuPopupFrame::Escape(PRBool& aHandledFlag)
 {
   mIncrementalString = NS_LITERAL_STRING("");
 
+  // See if we have a context menu open.
+  nsCOMPtr<nsIMenuParent> contextMenu;
+  GetContextMenu(getter_AddRefs(contextMenu));
+  if (contextMenu) {
+    // Get the context menu parent.
+    nsIFrame* childFrame;
+    CallQueryInterface(contextMenu, &childFrame);
+    nsIPopupSetFrame* popupSetFrame = GetPopupSetFrame(mPresContext);
+    if (popupSetFrame)
+      // Destroy the popup.
+      popupSetFrame->DestroyPopup(childFrame, PR_FALSE);
+    aHandledFlag = PR_TRUE;
+    return NS_OK;
+  }
+
   if (!mCurrentMenu)
     return NS_OK;
 
@@ -1542,6 +1584,12 @@ nsMenuPopupFrame::Enter()
 {
   mIncrementalString = NS_LITERAL_STRING("");
 
+  // See if we have a context menu open.
+  nsCOMPtr<nsIMenuParent> contextMenu;
+  GetContextMenu(getter_AddRefs(contextMenu));
+  if (contextMenu)
+    return contextMenu->Enter();
+
   // Give it to the child.
   if (mCurrentMenu)
     mCurrentMenu->Enter();
@@ -1549,6 +1597,26 @@ nsMenuPopupFrame::Enter()
   return NS_OK;
 }
 
+void 
+nsMenuPopupFrame::GetContextMenu(nsIMenuParent** aContextMenu)
+{
+  *aContextMenu = nsnull;
+  if (mIsContextMenu || !nsMenuFrame::sDismissalListener)
+    return;
+
+  nsCOMPtr<nsIMenuParent> menuParent;
+  nsMenuFrame::sDismissalListener->GetCurrentMenuParent(getter_AddRefs(menuParent));
+  if (!menuParent)
+    return;
+
+  PRBool isContextMenu;
+  menuParent->GetIsContextMenu(isContextMenu);
+  if (isContextMenu) {
+    *aContextMenu = menuParent;
+    NS_ADDREF(*aContextMenu);
+  }
+}
+
 nsIMenuFrame*
 nsMenuPopupFrame::FindMenuWithShortcut(nsIDOMKeyEvent* aKeyEvent, PRBool& doAction)
 {
@@ -1612,9 +1680,9 @@ nsMenuPopupFrame::FindMenuWithShortcut(nsIDOMKeyEvent* aKeyEvent, PRBool& doActi
       mIncrementalString = pressKey;
     else {
       if (mIncrementalString.Length() != 1 ||
-          GetCharAt(mIncrementalString, 0) != GetCharAt(pressKey, 0))
+          mIncrementalString.First() != pressKey.First())
           // If user typed the same key more than once, we should do a cycled one-key navigation
-      mIncrementalString.do_AppendFromElement(GetCharAt(pressKey, 0));
+      mIncrementalString.do_AppendFromElement(pressKey.First());
     }
   }
 
@@ -1747,15 +1815,24 @@ nsMenuPopupFrame::ShortcutNavigation(nsIDOMKeyEvent* aKeyEvent, PRBool& aHandled
 }
 
 NS_IMETHODIMP
-nsMenuPopupFrame::KeyboardNavigation(PRUint32 aDirection, PRBool& aHandledFlag)
+nsMenuPopupFrame::KeyboardNavigation(PRUint32 aKeyCode, PRBool& aHandledFlag)
 {
+  // See if we have a context menu open.
+  nsCOMPtr<nsIMenuParent> contextMenu;
+  GetContextMenu(getter_AddRefs(contextMenu));
+  if (contextMenu)
+    return contextMenu->KeyboardNavigation(aKeyCode, aHandledFlag);
+
+  nsNavigationDirection theDirection;
+  NS_DIRECTION_FROM_KEY_CODE(theDirection, aKeyCode);
+
   mIncrementalString = NS_LITERAL_STRING("");
 
   // This method only gets called if we're open.
-  if (!mCurrentMenu && (aDirection == NS_VK_RIGHT || aDirection == NS_VK_LEFT)) {
+  if (!mCurrentMenu && NS_DIRECTION_IS_INLINE(theDirection)) {
     // We've been opened, but we haven't had anything selected.
-    // We can handle RIGHT, but our parent handles LEFT.
-    if (aDirection == NS_VK_RIGHT) {
+    // We can handle End, but our parent handles Start.
+    if (theDirection == eNavigationDirection_End) {
       nsIMenuFrame* nextItem;
       GetNextMenuItem(nsnull, &nextItem);
       if (nextItem) {
@@ -1776,9 +1853,10 @@ nsMenuPopupFrame::KeyboardNavigation(PRUint32 aDirection, PRBool& aHandledFlag)
 
     if (isOpen) {
       // Give our child a shot.
-      mCurrentMenu->KeyboardNavigation(aDirection, aHandledFlag);
+      mCurrentMenu->KeyboardNavigation(aKeyCode, aHandledFlag);
     }
-    else if (aDirection == NS_VK_RIGHT && isContainer && !isDisabled) {
+    else if (theDirection == eNavigationDirection_End &&
+             isContainer && !isDisabled) {
       // The menu is not yet open. Open it and select the first item.
       aHandledFlag = PR_TRUE;
       mCurrentMenu->OpenMenu(PR_TRUE);
@@ -1789,17 +1867,17 @@ nsMenuPopupFrame::KeyboardNavigation(PRUint32 aDirection, PRBool& aHandledFlag)
   if (aHandledFlag)
     return NS_OK; // The child menu took it for us.
 
-  // For the vertical direction, we can move up or down.
-  if (aDirection == NS_VK_UP || aDirection == NS_VK_DOWN ||
-      aDirection == NS_VK_HOME || aDirection == NS_VK_END) {
+  // For block progression, we can move in either direction
+  if (NS_DIRECTION_IS_BLOCK(theDirection) ||
+      NS_DIRECTION_IS_BLOCK_TO_EDGE(theDirection)) {
 
     nsIMenuFrame* nextItem;
     
-    if (aDirection == NS_VK_UP)
+    if (theDirection == eNavigationDirection_Before)
       GetPreviousMenuItem(mCurrentMenu, &nextItem);
-    else if (aDirection == NS_VK_DOWN)
+    else if (theDirection == eNavigationDirection_After)
       GetNextMenuItem(mCurrentMenu, &nextItem);
-    else if (aDirection == NS_VK_HOME)
+    else if (theDirection == eNavigationDirection_First)
       GetNextMenuItem(nsnull, &nextItem);
     else
       GetPreviousMenuItem(nsnull, &nextItem);
@@ -1809,7 +1887,7 @@ nsMenuPopupFrame::KeyboardNavigation(PRUint32 aDirection, PRBool& aHandledFlag)
     aHandledFlag = PR_TRUE;
   }
   else if (mCurrentMenu && isContainer && isOpen) {
-    if (aDirection == NS_VK_LEFT) {
+    if (theDirection == eNavigationDirection_Start) {
       // Close it up.
       mCurrentMenu->OpenMenu(PR_FALSE);
       aHandledFlag = PR_TRUE;
@@ -1890,7 +1968,8 @@ nsMenuPopupFrame::DismissChain()
   nsIFrame* frame;
   GetParent(&frame);
   if (frame) {
-    nsCOMPtr<nsIMenuFrame> menuFrame = do_QueryInterface(frame);
+    nsIMenuFrame *menuFrame = nsnull;
+    CallQueryInterface(frame, &menuFrame);
     if (!menuFrame) {
       nsIPopupSetFrame* popupSetFrame = GetPopupSetFrame(mPresContext);
       if (popupSetFrame) {
@@ -1898,7 +1977,7 @@ nsMenuPopupFrame::DismissChain()
         if (mCurrentMenu)
           mCurrentMenu->SelectMenu(PR_FALSE);
         // Destroy the popup.
-        popupSetFrame->DestroyPopup(this);
+        popupSetFrame->DestroyPopup(this, PR_TRUE);
       }
       return NS_OK;
     }
@@ -1906,8 +1985,8 @@ nsMenuPopupFrame::DismissChain()
     menuFrame->OpenMenu(PR_FALSE);
 
     // Get the parent.
-    nsCOMPtr<nsIMenuParent> menuParent;
-    menuFrame->GetMenuParent(getter_AddRefs(menuParent));
+    nsIMenuParent* menuParent;
+    menuFrame->GetMenuParent(&menuParent);
     if (menuParent)
       menuParent->DismissChain();
   }
@@ -2102,7 +2181,7 @@ nsMenuPopupFrame::GetFrameForPoint(nsIPresContext* aPresContext,
 //
 // The code below melds the two cases together.
 //
-NS_IMETHODIMP_(void)
+NS_IMETHODIMP
 nsMenuPopupFrame::Notify(nsITimer* aTimer)
 {
   // Our timer has fired. 
@@ -2155,6 +2234,7 @@ nsMenuPopupFrame::Notify(nsITimer* aTimer)
   
   mCloseTimer = nsnull;
   mTimerMenu = nsnull;
+  return NS_OK;
 }
 
 NS_IMETHODIMP
