@@ -247,7 +247,7 @@ NS_IMETHODIMP nsAbQueryLDAPMessageListener::OnLDAPMessage(nsILDAPMessage *aMessa
     return rv;
 }
 
-NS_IMETHODIMP nsAbQueryLDAPMessageListener::OnLDAPInit(nsresult aStatus)
+NS_IMETHODIMP nsAbQueryLDAPMessageListener::OnLDAPInit(nsILDAPConnection *aConn, nsresult aStatus)
 {
     nsresult rv;
     nsXPIDLString passwd;
@@ -342,7 +342,7 @@ NS_IMETHODIMP nsAbQueryLDAPMessageListener::OnLDAPInit(nsresult aStatus)
         // get the window watcher service, so we can get an auth prompter
         //
         nsCOMPtr<nsIWindowWatcher> windowWatcherSvc = 
-            do_GetService("@mozilla.org/embedcomp/window-watcher;1", &rv);
+            do_GetService(NS_WINDOWWATCHER_CONTRACTID, &rv);
         if (NS_FAILED(rv)) {
             NS_ERROR("nsAbQueryLDAPMessageListener::OnLDAPInit():"
                      " couldn't get window watcher service.");
@@ -397,11 +397,11 @@ NS_IMETHODIMP nsAbQueryLDAPMessageListener::OnLDAPInit(nsresult aStatus)
                      PROXY_SYNC | PROXY_ALWAYS,
                      getter_AddRefs(proxyListener));
 
-    rv = ldapOperation->Init(mConnection, proxyListener);
+    rv = ldapOperation->Init(mConnection, proxyListener, nsnull);
     NS_ENSURE_SUCCESS(rv, rv);
 
     // Bind
-    rv = ldapOperation->SimpleBind(passwd);
+    rv = ldapOperation->SimpleBind(NS_ConvertUCS2toUTF8(passwd));
     NS_ENSURE_SUCCESS(rv, rv);
 
     return rv;
@@ -460,31 +460,26 @@ nsresult nsAbQueryLDAPMessageListener::OnLDAPMessageBind (nsILDAPMessage *aMessa
 									this, PROXY_SYNC | PROXY_ALWAYS, getter_AddRefs(proxyListener));
     NS_ENSURE_SUCCESS(rv, rv);
 
-    rv = mSearchOperation->Init (mConnection, proxyListener);
+    rv = mSearchOperation->Init (mConnection, proxyListener, nsnull);
     NS_ENSURE_SUCCESS(rv, rv);
 
-    nsXPIDLCString dn;
-    rv = mUrl->GetDn (getter_Copies (dn));
+    nsCAutoString dn;
+    rv = mUrl->GetDn (dn);
     NS_ENSURE_SUCCESS(rv, rv);
 
     PRInt32 scope;
     rv = mUrl->GetScope (&scope);
     NS_ENSURE_SUCCESS(rv, rv);
 
-    nsXPIDLCString filter;
-    rv = mUrl->GetFilter (getter_Copies (filter));
+    nsCAutoString filter;
+    rv = mUrl->GetFilter (filter);
     NS_ENSURE_SUCCESS(rv, rv);
 
     CharPtrArrayGuard attributes;
     rv = mUrl->GetAttributes (attributes.GetSizeAddr (), attributes.GetArrayAddr ());
     NS_ENSURE_SUCCESS(rv, rv);
 
-    // when we called SetSpec(), our spec contained UTF8 data
-    // so when we call GetFilter(), it's not going to be ASCII.
-    // it will be UTF8, so we need to convert from UTF8 to UCS2
-    // see bug #124995
-    rv = mSearchOperation->SearchExt (NS_ConvertUTF8toUCS2(dn).get(), scope,
-            NS_ConvertUTF8toUCS2(filter).get(),
+    rv = mSearchOperation->SearchExt (dn, scope, filter,
             attributes.GetSize (), attributes.GetArray (),
             mTimeOut, mResultLimit);
     NS_ENSURE_SUCCESS(rv, rv);
@@ -507,21 +502,21 @@ nsresult nsAbQueryLDAPMessageListener::OnLDAPMessageSearchEntry (nsILDAPMessage
     rv = aMessage->GetAttributes(attrs.GetSizeAddr(), attrs.GetArrayAddr());
     NS_ENSURE_SUCCESS(rv, rv);
 
-    nsCAutoString n;
+    nsCAutoString propertyName;
     for (PRUint32 i = 0; i < properties.GetSize(); i++)
     {
-        n.Assign (properties[i]);
+        propertyName.Assign (properties[i]);
 
         nsAbDirectoryQueryPropertyValue* _propertyValue = 0;
-        if (n.Equals("card:nsIAbCard"))
+        if (propertyName.Equals("card:nsIAbCard"))
         {
             // Meta property
-            nsXPIDLString dn;
-            rv = aMessage->GetDn (getter_Copies (dn));
+            nsCAutoString dn;
+            rv = aMessage->GetDn (dn);
             NS_ENSURE_SUCCESS(rv, rv);
 
             nsCOMPtr<nsIAbCard> card;
-            rv = mDirectoryQuery->CreateCard (mUrl, NS_ConvertUCS2toUTF8(dn).get(), getter_AddRefs (card));
+            rv = mDirectoryQuery->CreateCard (mUrl, dn.get(), getter_AddRefs (card));
             NS_ENSURE_SUCCESS(rv, rv);
 
             PRBool hasSetCardProperty = PR_FALSE;
@@ -533,22 +528,36 @@ nsresult nsAbQueryLDAPMessageListener::OnLDAPMessageSearchEntry (nsILDAPMessage
             if (hasSetCardProperty == PR_FALSE)
                 continue;
 
-            _propertyValue = new nsAbDirectoryQueryPropertyValue(n.get (), card);
+            _propertyValue = new nsAbDirectoryQueryPropertyValue(propertyName.get (), card);
             if (_propertyValue == NULL)
                 return NS_ERROR_OUT_OF_MEMORY;
 
         }
         else
         {
-            const MozillaLdapPropertyRelation* p =
-                MozillaLdapPropertyRelator::findLdapPropertyFromMozilla (n.get ());
-
-            if (!p)
+            if (!MozillaLdapPropertyRelator::findLdapPropertyFromMozilla (propertyName.get ()))
                 continue;
 
+            const MozillaLdapPropertyRelation* relation ;
+
             for (PRUint32 j = 0; j < attrs.GetSize(); j++)
             {
-                if (nsCRT::strcasecmp (p->ldapProperty, attrs[j]) == 0)
+                relation = MozillaLdapPropertyRelator::findMozillaPropertyFromLdap (attrs[j]);
+                if (!relation)
+                    continue;
+                /*
+                 * This change is necessary due to a side effect of #124022. The list of
+                 * requested attributes is created in reverse order than how they appear
+                 * in nsAbLDAPProperties.cpp. Thus while "surname" and "sn" both map to
+                 * LastName, "sn" will be returned by findLdapPropertyFromMozilla() as it
+                 * appears first in the hash table but "surname" will be returned by the 
+                 * request. 
+                 *
+                 * Rather than simply reversing the order, an alternative is to compare
+                 * the mapped Mozilla attributes where a one to one match exists.
+                */
+
+                if (nsCRT::strcasecmp (relation->mozillaProperty, propertyName.get()) == 0)
                 {
                     PRUnicharPtrArrayGuard vals;
                     rv = aMessage->GetValues (attrs[j], vals.GetSizeAddr(), vals.GetArrayAddr());
@@ -557,7 +566,7 @@ nsresult nsAbQueryLDAPMessageListener::OnLDAPMessageSearchEntry (nsILDAPMessage
                     if (vals.GetSize() == 0)
                         break;
 
-                    _propertyValue = new nsAbDirectoryQueryPropertyValue(n.get (), vals[0]);
+                    _propertyValue = new nsAbDirectoryQueryPropertyValue(propertyName.get (), vals[0]);
                     if (_propertyValue == NULL)
                         return NS_ERROR_OUT_OF_MEMORY;
                     break;
@@ -690,6 +699,23 @@ NS_IMETHODIMP nsAbLDAPDirectoryQuery::DoQuery(nsIAbDirectoryQueryArguments* argu
     rv = nsAbBoolExprToLDAPFilter::Convert (expression, filter);
     NS_ENSURE_SUCCESS(rv, rv);
 
+    /*
+     * Mozilla itself cannot arrive here with a blank filter
+     * as the nsAbLDAPDirectory::StartSearch() disallows it.
+     * But 3rd party LDAP query integration with Mozilla begins 
+     * in this method.
+     *
+     * Default the filter string if blank, otherwise it gets
+     * set to (objectclass=*) which returns everything. Set 
+     * the default to (objectclass=inetorgperson) as this 
+     * is the most appropriate default objectclass which is 
+     * central to the makeup of the mozilla ldap address book 
+     * entries.
+    */
+    if(filter.IsEmpty())
+    {
+        filter += NS_LITERAL_CSTRING("(objectclass=inetorgperson)");
+    }
 
     // Set up the search ldap url
     rv = GetLDAPURL (getter_AddRefs (mDirectoryUrl));
@@ -703,8 +729,8 @@ NS_IMETHODIMP nsAbLDAPDirectoryQuery::DoQuery(nsIAbDirectoryQueryArguments* argu
     rv = mDirectoryUrl->GetPort(&port);
     NS_ENSURE_SUCCESS(rv, rv);
 
-    nsXPIDLCString dn;
-    rv = mDirectoryUrl->GetDn(getter_Copies (dn));
+    nsCAutoString dn;
+    rv = mDirectoryUrl->GetDn(dn);
     NS_ENSURE_SUCCESS(rv, rv);
 
     PRUint32 options;
@@ -776,8 +802,8 @@ NS_IMETHODIMP nsAbLDAPDirectoryQuery::DoQuery(nsIAbDirectoryQueryArguments* argu
 
     // Now lets initialize the LDAP connection properly. We'll kick
     // off the bind operation in the callback function, |OnLDAPInit()|.
-    rv = ldapConnection->Init(host.get(), port, options, mLogin.get(),
-                              messageListener);
+    rv = ldapConnection->Init(host.get(), port, options, mLogin,
+                              messageListener, nsnull);
     NS_ENSURE_SUCCESS(rv, rv);
 
     return rv;
@@ -840,12 +866,12 @@ nsresult nsAbLDAPDirectoryQuery::getLdapReturnAttributes (
     rv = arguments->GetReturnProperties (properties.GetSizeAddr(), properties.GetArrayAddr());
     NS_ENSURE_SUCCESS(rv, rv);
 
-    nsCAutoString n;
+    nsCAutoString propertyName;
     for (PRUint32 i = 0; i < properties.GetSize(); i++)
     {
-        n.Assign (properties[i]);
+        propertyName.Assign (properties[i]);
 
-        if (n.Equals("card:nsIAbCard"))
+        if (propertyName.Equals("card:nsIAbCard"))
         {
             // Meta property
             // require all attributes
@@ -855,15 +881,15 @@ nsresult nsAbLDAPDirectoryQuery::getLdapReturnAttributes (
             break;
         }
 
-        const MozillaLdapPropertyRelation* p=
-            MozillaLdapPropertyRelator::findLdapPropertyFromMozilla (n.get ());
-        if (!p)
+        const MozillaLdapPropertyRelation* tableEntry=
+            MozillaLdapPropertyRelator::findLdapPropertyFromMozilla (propertyName.get ());
+        if (!tableEntry)
             continue;
 
         if (i)
             returnAttributes.Append (",");
 
-        returnAttributes.Append (p->ldapProperty);
+        returnAttributes.Append (tableEntry->ldapProperty);
     }
 
     return rv;
