@@ -21,6 +21,7 @@
  *
  * Contributor(s):
  *   Pierre Phaneuf <pp@ludusdesign.com>
+ *   Seth Spitzer <sspitzer@netscape.com>
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or 
@@ -52,8 +53,8 @@
 #include "nsIImportService.h"
 #include "nsMsgBaseCID.h"
 #include "nsIMsgFilterService.h"
-
-static NS_DEFINE_CID(kMsgFilterServiceCID, NS_MSGFILTERSERVICE_CID);
+#include "nsIFileStreams.h"
+#include "nsISupportsObsolete.h"
 
 // unicode "%s" format string
 static const PRUnichar unicodeFormatter[] = {
@@ -66,13 +67,13 @@ static const PRUnichar unicodeFormatter[] = {
 nsMsgFilterList::nsMsgFilterList() :
     m_fileVersion(0)
 {
-	// I don't know how we're going to report this error if we failed to create the isupports array...
-	nsresult rv;
-	rv = NS_NewISupportsArray(getter_AddRefs(m_filters));
-	m_loggingEnabled = PR_FALSE;
-	m_curFilter = nsnull;
+  // I don't know how we're going to report this error if we failed to create the isupports array...
+  nsresult rv = NS_NewISupportsArray(getter_AddRefs(m_filters));
+  m_loggingEnabled = PR_FALSE;
+  m_curFilter = nsnull;
   m_arbitraryHeaders.SetLength(0);
-	NS_INIT_REFCNT();
+
+  NS_INIT_ISUPPORTS();
 }
 
 NS_IMPL_ADDREF(nsMsgFilterList)
@@ -81,18 +82,17 @@ NS_IMPL_QUERY_INTERFACE1(nsMsgFilterList, nsIMsgFilterList)
 
 NS_IMETHODIMP nsMsgFilterList::CreateFilter(const PRUnichar *name,class nsIMsgFilter **aFilter)
 {
-	NS_ENSURE_ARG_POINTER(aFilter);
+  NS_ENSURE_ARG_POINTER(aFilter);
 
-	nsMsgFilter *filter = new nsMsgFilter;
-    NS_ENSURE_TRUE(filter, NS_ERROR_OUT_OF_MEMORY);
+  nsMsgFilter *filter = new nsMsgFilter;
+  NS_ENSURE_TRUE(filter, NS_ERROR_OUT_OF_MEMORY);
     
-	*aFilter = filter;
-    NS_ADDREF(*aFilter);
+  NS_ADDREF(*aFilter = filter);
     
-    filter->SetFilterName(name);
-    filter->SetFilterList(this);
+  filter->SetFilterName(name);
+  filter->SetFilterList(this);
     
-	return NS_OK;
+  return NS_OK;
 }
 
 NS_IMPL_GETSET(nsMsgFilterList, LoggingEnabled, PRBool, m_loggingEnabled);
@@ -118,6 +118,136 @@ NS_IMETHODIMP nsMsgFilterList::SaveToFile(nsIOFileStream *stream)
 	return SaveTextFilters(stream);
 }
 
+NS_IMETHODIMP nsMsgFilterList::EnsureLogFile()
+{
+  nsCOMPtr <nsIFileSpec> file;
+  nsresult rv = GetLogFileSpec(getter_AddRefs(file));
+  NS_ENSURE_SUCCESS(rv,rv);
+
+  PRBool exists;
+  rv = file->Exists(&exists);
+  if (NS_SUCCEEDED(rv) && !exists) {
+    rv = file->Touch();
+    NS_ENSURE_SUCCESS(rv,rv);
+  }
+  return NS_OK;
+}
+
+nsresult nsMsgFilterList::TruncateLog()
+{
+  // this will flush and close the steam
+  nsresult rv = SetLogStream(nsnull);
+  NS_ENSURE_SUCCESS(rv,rv);
+
+  nsCOMPtr <nsIFileSpec> file;
+  rv = GetLogFileSpec(getter_AddRefs(file));
+  NS_ENSURE_SUCCESS(rv,rv);
+
+  rv = file->Truncate(0);
+  NS_ENSURE_SUCCESS(rv,rv);
+  return rv;
+}
+
+NS_IMETHODIMP nsMsgFilterList::ClearLog()
+{
+  PRBool loggingEnabled = m_loggingEnabled;
+  
+  // disable logging while clearing
+  m_loggingEnabled = PR_FALSE;
+
+  nsresult rv = TruncateLog();
+  NS_ASSERTION(NS_SUCCEEDED(rv), "failed to truncate filter log");
+
+  m_loggingEnabled = loggingEnabled;
+  return NS_OK;
+}
+
+nsresult 
+nsMsgFilterList::GetLogFileSpec(nsIFileSpec **aFileSpec)
+{
+  NS_ENSURE_ARG_POINTER(aFileSpec);
+
+  nsCOMPtr <nsIMsgFolder> folder;
+  nsresult rv = GetFolder(getter_AddRefs(folder));
+  NS_ENSURE_SUCCESS(rv,rv);
+
+  nsCOMPtr <nsIMsgIncomingServer> server;
+  rv = folder->GetServer(getter_AddRefs(server));
+  NS_ENSURE_SUCCESS(rv,rv);
+
+  rv = server->GetLocalPath(aFileSpec);
+  NS_ENSURE_SUCCESS(rv,rv);
+
+  rv = (*aFileSpec)->AppendRelativeUnixPath("filterlog.html");
+  NS_ENSURE_SUCCESS(rv,rv);
+  return NS_OK;
+}
+
+NS_IMETHODIMP
+nsMsgFilterList::GetLogURL(char **aLogURL)
+{
+  NS_ENSURE_ARG_POINTER(aLogURL);
+
+  nsCOMPtr <nsIFileSpec> file;
+  nsresult rv = GetLogFileSpec(getter_AddRefs(file));
+  NS_ENSURE_SUCCESS(rv,rv);
+  
+  rv = file->GetURLString(aLogURL);
+  NS_ENSURE_SUCCESS(rv,rv);
+  return NS_OK;
+}
+
+NS_IMETHODIMP
+nsMsgFilterList::SetLogStream(nsIOutputStream *aLogStream)
+{
+  // if there is a log stream already, close it
+  if (m_logStream) {
+    // will flush
+    nsresult rv = m_logStream->Close();
+    NS_ENSURE_SUCCESS(rv,rv);
+  }
+
+  m_logStream = aLogStream;
+  return NS_OK;
+}
+
+NS_IMETHODIMP
+nsMsgFilterList::GetLogStream(nsIOutputStream **aLogStream)
+{
+  NS_ENSURE_ARG_POINTER(aLogStream);
+
+  nsresult rv;
+
+  if (!m_logStream) {
+    nsCOMPtr <nsIFileSpec> file;
+    rv = GetLogFileSpec(getter_AddRefs(file));
+    NS_ENSURE_SUCCESS(rv,rv);
+
+    nsXPIDLCString nativePath;
+    rv = file->GetNativePath(getter_Copies(nativePath));
+    NS_ENSURE_SUCCESS(rv,rv);
+
+    nsCOMPtr <nsILocalFile> logFile = do_CreateInstance(NS_LOCAL_FILE_CONTRACTID, &rv);
+    NS_ENSURE_SUCCESS(rv,rv);
+
+    rv = logFile->InitWithNativePath(nsDependentCString(nativePath));
+    NS_ENSURE_SUCCESS(rv,rv);
+
+    // append to the end of the log file
+    rv = NS_NewLocalFileOutputStream(getter_AddRefs(m_logStream),
+                                   logFile,
+                                   PR_CREATE_FILE | PR_WRONLY | PR_APPEND,
+                                   0600);
+    NS_ENSURE_SUCCESS(rv,rv);
+
+    if (!m_logStream)
+      return NS_ERROR_FAILURE;
+  }
+ 
+  NS_ADDREF(*aLogStream = m_logStream);
+  return NS_OK;
+}
+
 NS_IMETHODIMP
 nsMsgFilterList::ApplyFiltersToHdr(nsMsgFilterTypeType filterType,
                                    nsIMsgDBHdr *msgHdr,
@@ -154,7 +284,7 @@ nsMsgFilterList::ApplyFiltersToHdr(nsMsgFilterTypeType filterType,
 				matchTermStatus = filter->MatchHdr(msgHdr, folder, db, headers, headersSize, &result);
 				if (NS_SUCCEEDED(matchTermStatus) && result && listener)
 				{
-					PRBool applyMore;
+					PRBool applyMore = PR_TRUE;
 
 					ret  = listener->ApplyFilterHit(filter, msgWindow, &applyMore);
 					if (NS_FAILED(ret) || !applyMore)
@@ -170,13 +300,11 @@ NS_IMETHODIMP
 nsMsgFilterList::SetDefaultFile(nsIFileSpec *aFileSpec)
 {
     nsresult rv;
-    m_defaultFile = 
-        do_CreateInstance(NS_FILESPEC_CONTRACTID, &rv);
+    m_defaultFile = do_CreateInstance(NS_FILESPEC_CONTRACTID, &rv);
     NS_ENSURE_SUCCESS(rv, rv);
     
     rv = m_defaultFile->FromFileSpec(aFileSpec);
     NS_ENSURE_SUCCESS(rv, rv);
-
     return NS_OK;
 }
 
@@ -204,7 +332,7 @@ nsMsgFilterList::SaveToDefaultFile()
 {
     nsresult rv;
     nsCOMPtr<nsIMsgFilterService> filterService =
-        do_GetService(kMsgFilterServiceCID, &rv);
+        do_GetService(NS_MSGFILTERSERVICE_CONTRACTID, &rv);
     NS_ENSURE_SUCCESS(rv, rv);
 
     return filterService->SaveFilterList(this, m_defaultFile);
@@ -636,7 +764,6 @@ nsresult nsMsgFilterList::SaveTextFilters(nsIOFileStream *aStream)
 
 nsMsgFilterList::~nsMsgFilterList()
 {
-
 	// filters should be released for free, because only isupports array
 	// is holding onto them, right?
 //	PRUint32			filterCount;
@@ -902,7 +1029,24 @@ NS_IMETHODIMP nsMsgFilterList::GetArbitraryHeaders(char **aResult)
   return NS_OK;
 }
 
+NS_IMETHODIMP nsMsgFilterList::FlushLogIfNecessary()
+{
+  // only flush the log if we are logging
+  PRBool loggingEnabled = PR_FALSE;
+  nsresult rv = GetLoggingEnabled(&loggingEnabled);
+  NS_ENSURE_SUCCESS(rv,rv);
 
+  if (loggingEnabled) 
+  {
+    nsCOMPtr <nsIOutputStream> logStream;
+    rv = GetLogStream(getter_AddRefs(logStream));    
+    if (NS_SUCCEEDED(rv) && logStream) {
+      rv = logStream->Flush();
+      NS_ENSURE_SUCCESS(rv,rv);
+    }
+  }
+  return rv;
+}
 
 #ifdef DEBUG
 void nsMsgFilterList::Dump()
