@@ -49,14 +49,14 @@
 #include "nsIRequestObserver.h"
 #include "nsSpecialSystemDirectory.h"
 #include "nsIFileStream.h"
-static NS_DEFINE_CID(kMsgAccountManagerCID, NS_MSGACCOUNTMANAGER_CID);
+#include "nsIMsgCopyService.h"
 static NS_DEFINE_CID(kRDFServiceCID, NS_RDFSERVICE_CID);
 
 NS_IMPL_ISUPPORTS2(nsImapOfflineSync, nsIUrlListener, nsIMsgCopyServiceListener)
 
 nsImapOfflineSync::nsImapOfflineSync(nsIMsgWindow *window, nsIUrlListener *listener, nsIMsgFolder *singleFolderOnly)
 {
-  NS_INIT_REFCNT();
+  NS_INIT_ISUPPORTS();
   m_singleFolderToUpdate = singleFolderOnly;
   m_window = window;
   // not the perfect place for this, but I think it will work.
@@ -345,11 +345,13 @@ nsImapOfflineSync::ProcessAppendMsgOperation(nsIMsgOfflineImapOperation *current
                   if (NS_SUCCEEDED(rv))
                   {
                     m_curTempFile = tempFileSpec;
-                    rv = destFolder->CopyFileMessage(tempFileSpec,
+                    nsCOMPtr<nsIMsgCopyService> copyService = do_GetService(NS_MSGCOPYSERVICE_CONTRACTID);
+                    if (copyService)
+                      rv = copyService->CopyFileMessage(tempFileSpec, destFolder,
                       /* nsIMsgDBHdr* msgToReplace */ nsnull,
                       PR_TRUE /* isDraftOrTemplate */,
-                      m_window,
-                      this);
+                        this,
+                        m_window);
                   }
                   else
                     m_curTempFile->Delete(PR_FALSE);
@@ -440,7 +442,9 @@ void nsImapOfflineSync::ProcessMoveOperation(nsIMsgOfflineImapOperation *current
               messages->AppendElement(iSupports);
             }
           }
-          destFolder->CopyMessages(m_currentFolder, messages, PR_TRUE, m_window, this, PR_FALSE, PR_FALSE);
+          nsCOMPtr<nsIMsgCopyService> copyService = do_GetService(NS_MSGCOPYSERVICE_CONTRACTID, &rv);
+          if (copyService)
+            copyService->CopyMessages(m_currentFolder, messages, destFolder, PR_TRUE, this, m_window, PR_FALSE);
         }
       }
     }
@@ -535,7 +539,9 @@ void nsImapOfflineSync::ProcessCopyOperation(nsIMsgOfflineImapOperation *current
               messages->AppendElement(iSupports);
             }
           }
-          destFolder->CopyMessages(m_currentFolder, messages, PR_FALSE, m_window, this, PR_FALSE, PR_FALSE);
+          nsCOMPtr<nsIMsgCopyService> copyService = do_GetService(NS_MSGCOPYSERVICE_CONTRACTID, &rv);
+          if (copyService)
+            copyService->CopyMessages(m_currentFolder, messages, destFolder, PR_FALSE, this, m_window, PR_FALSE);
         }
       }
     }
@@ -941,7 +947,7 @@ nsresult nsImapOfflineDownloader::ProcessNextOperation()
     // Update the INBOX first so the updates on the remaining
     // folders pickup the results of any filter moves.
     nsCOMPtr<nsIMsgAccountManager> accountManager = 
-             do_GetService(kMsgAccountManagerCID, &rv);
+             do_GetService(NS_MSGACCOUNTMANAGER_CONTRACTID, &rv);
     if (NS_FAILED(rv)) return rv;
     nsCOMPtr<nsISupportsArray> servers;
   
