@@ -44,6 +44,7 @@
 #include "nsISupportsArray.h"
 #include "nsIImportAddressBooks.h"
 #include "nsIImportGeneric.h"
+#include "nsXPCOM.h"
 #include "nsISupportsPrimitives.h"
 #include "nsIImportABDescriptor.h"
 #include "nsIImportFieldMap.h"
@@ -67,12 +68,10 @@
 
 #include "ImportDebug.h"
 
-static NS_DEFINE_CID(kAddressBookDBCID, NS_ADDRDATABASE_CID);
 static NS_DEFINE_CID(kAbDirectoryCID, NS_ABDIRECTORY_CID);
 static NS_DEFINE_CID(kStandardUrlCID, NS_STANDARDURL_CID);
-static NS_DEFINE_CID(kAddrBookSessionCID, NS_ADDRBOOKSESSION_CID);
 static NS_DEFINE_CID(kRDFServiceCID, NS_RDFSERVICE_CID);
-static NS_DEFINE_CID(kSupportsWStringCID, NS_SUPPORTS_WSTRING_CID);
+static NS_DEFINE_CID(kSupportsWStringCID, NS_SUPPORTS_STRING_CID);
 static NS_DEFINE_CID(kProxyObjectManagerCID, NS_PROXYEVENT_MANAGER_CID);
 
 
@@ -102,8 +101,8 @@ public:
 	/* boolean WantsProgress (); */
 	NS_IMETHOD WantsProgress(PRBool *_retval);
 
-    /* boolean BeginImport (in nsISupportsWString successLog, in nsISupportsWString errorLog, in boolean isAddrLocHome); */
-    NS_IMETHOD BeginImport(nsISupportsWString *successLog, nsISupportsWString *errorLog, PRBool isAddrLocHome, PRBool *_retval) ;
+    /* boolean BeginImport (in nsISupportsString successLog, in nsISupportsString errorLog, in boolean isAddrLocHome); */
+    NS_IMETHOD BeginImport(nsISupportsString *successLog, nsISupportsString *errorLog, PRBool isAddrLocHome, PRBool *_retval) ;
 
 	/* boolean ContinueImport (); */
 	NS_IMETHOD ContinueImport(PRBool *_retval);
@@ -120,7 +119,7 @@ private:
 	void	GetDefaultFieldMap( void);
 
 public:
-	static void	SetLogs( nsString& success, nsString& error, nsISupportsWString *pSuccess, nsISupportsWString *pError);
+	static void	SetLogs( nsString& success, nsString& error, nsISupportsString *pSuccess, nsISupportsString *pError);
 	static void ReportError( PRUnichar *pName, nsString *pStream);
 
 private:
@@ -133,8 +132,8 @@ private:
 	PRBool						m_gotLocation;
 	PRBool						m_found;
 	PRBool						m_userVerify;
-	nsISupportsWString *		m_pSuccessLog;
-	nsISupportsWString *		m_pErrorLog;
+	nsISupportsString *		m_pSuccessLog;
+	nsISupportsString *		m_pErrorLog;
 	PRUint32					m_totalSize;
 	PRBool						m_doImport;
 	AddressThreadData *			m_pThreadData;
@@ -152,8 +151,8 @@ public:
 	nsISupportsArray *			books;
 	nsIImportAddressBooks *		addressImport;
 	nsIImportFieldMap *			fieldMap;
-	nsISupportsWString *		successLog;
-	nsISupportsWString *		errorLog;
+	nsISupportsString *		successLog;
+	nsISupportsString *		errorLog;
 	char *						pDestinationUri;
 	PRBool                      bAddrLocInput ;
 
@@ -185,7 +184,7 @@ nsresult NS_NewGenericAddressBooks(nsIImportGeneric** aImportGeneric)
 
 nsImportGenericAddressBooks::nsImportGenericAddressBooks()
 {
-    NS_INIT_REFCNT();
+    NS_INIT_ISUPPORTS();
 	m_pInterface = nsnull;
 	m_pBooks = nsnull;
 	m_pSuccessLog = nsnull;
@@ -265,7 +264,7 @@ NS_IMETHODIMP nsImportGenericAddressBooks::GetData(const char *dataId, nsISuppor
 			nsCOMPtr<nsIURL>	url;
 			rv = nsComponentManager::CreateInstance( kStandardUrlCID, nsnull, NS_GET_IID(nsIURL), getter_AddRefs( url));
 			if (NS_SUCCEEDED( rv)) {
-				url->SetSpec( m_pDestinationUri);
+				url->SetSpec( nsDependentCString(m_pDestinationUri));
 				*_retval = url;
 				NS_IF_ADDREF( *_retval);
 			}
@@ -303,8 +302,8 @@ NS_IMETHODIMP nsImportGenericAddressBooks::GetData(const char *dataId, nsISuppor
 		}
 		IMPORT_LOG1( "Requesting sample data #: %ld\n", (long)rNum);
 		if (m_pInterface) {
-			nsCOMPtr<nsISupportsWString>	data;
-			rv = nsComponentManager::CreateInstance( kSupportsWStringCID, nsnull, NS_GET_IID(nsISupportsWString), getter_AddRefs( data));
+			nsCOMPtr<nsISupportsString>	data;
+			rv = nsComponentManager::CreateInstance( kSupportsWStringCID, nsnull, NS_GET_IID(nsISupportsString), getter_AddRefs( data));
 			if (NS_FAILED( rv))
 				return( rv);
 			PRUnichar *	pData = nsnull;
@@ -313,7 +312,7 @@ NS_IMETHODIMP nsImportGenericAddressBooks::GetData(const char *dataId, nsISuppor
 			if (NS_FAILED( rv))
 				return( rv);
 			if (found) {
-				data->SetData( pData);
+				data->SetData(nsDependentString(pData));
 				*_retval = data;
 				NS_ADDREF( *_retval);
 			}
@@ -358,7 +357,9 @@ NS_IMETHODIMP nsImportGenericAddressBooks::SetData( const char *dataId, nsISuppo
 				if (m_pDestinationUri)
 					nsCRT::free( m_pDestinationUri);
 				m_pDestinationUri = nsnull;
-				url->GetSpec( &m_pDestinationUri);
+                nsCAutoString spec;
+				url->GetSpec(spec);
+                m_pDestinationUri = ToNewCString(spec);
 			}
 		}
 	}
@@ -539,38 +540,22 @@ NS_IMETHODIMP nsImportGenericAddressBooks::WantsProgress(PRBool *_retval)
 	return( NS_OK);
 }
 
-void nsImportGenericAddressBooks::SetLogs( nsString& success, nsString& error, nsISupportsWString *pSuccess, nsISupportsWString *pError)
+void nsImportGenericAddressBooks::SetLogs( nsString& success, nsString& error, nsISupportsString *pSuccess, nsISupportsString *pError)
 {
-	nsString	str;
-	PRUnichar *	pStr = nsnull;
+	nsAutoString str;
 	if (pSuccess) {
-		pSuccess->GetData( &pStr);
-		if (pStr) {
-			str = pStr;
-			nsCRT::free( pStr);
-			pStr = nsnull;
-			str.Append( success);
-			pSuccess->SetData( str.get());
-		}
-		else {
-			pSuccess->SetData( success.get());			
-		}
+		pSuccess->GetData(str);
+        str.Append(success);
+        pSuccess->SetData(success);
 	}
 	if (pError) {
-		pError->GetData( &pStr);
-		if (pStr) {
-			str = pStr;
-			nsCRT::free( pStr);
-			str.Append( error);
-			pError->SetData( str.get());
-		}
-		else {
-			pError->SetData( error.get());			
-		}
+		pError->GetData(str);
+        str.Append(error);
+        pError->SetData(error);
 	}	
 }
 
-NS_IMETHODIMP nsImportGenericAddressBooks::BeginImport(nsISupportsWString *successLog, nsISupportsWString *errorLog, PRBool isAddrLocHome, PRBool *_retval)
+NS_IMETHODIMP nsImportGenericAddressBooks::BeginImport(nsISupportsString *successLog, nsISupportsString *errorLog, PRBool isAddrLocHome, PRBool *_retval)
 {
 	NS_PRECONDITION(_retval != nsnull, "null ptr");
     if (!_retval)
@@ -791,7 +776,7 @@ nsIAddrDatabase *GetAddressBook( const PRUnichar *name, PRBool makeNew)
 	// Note to Candice: This should return an nsIFileSpec, not a nsFileSpec
 	nsFileSpec *					dbPath = nsnull;
 
-	NS_WITH_PROXIED_SERVICE(nsIAddrBookSession, abSession, kAddrBookSessionCID, NS_UI_THREAD_EVENTQ, &rv); 
+	NS_WITH_PROXIED_SERVICE(nsIAddrBookSession, abSession, NS_ADDRBOOKSESSION_CONTRACTID, NS_UI_THREAD_EVENTQ, &rv); 
 	
 	if (NS_SUCCEEDED(rv))
 		abSession->GetUserProfileDirectory(&dbPath);
@@ -803,7 +788,7 @@ nsIAddrDatabase *GetAddressBook( const PRUnichar *name, PRBool makeNew)
 		
 		IMPORT_LOG0( "Getting the address database factory\n");
 
-		NS_WITH_PROXIED_SERVICE(nsIAddrDatabase, addrDBFactory, kAddressBookDBCID, NS_UI_THREAD_EVENTQ, &rv);
+		NS_WITH_PROXIED_SERVICE(nsIAddrDatabase, addrDBFactory, NS_ADDRDATABASE_CONTRACTID, NS_UI_THREAD_EVENTQ, &rv);
 		if (NS_SUCCEEDED(rv) && addrDBFactory) {
 			
 			IMPORT_LOG0( "Opening the new address book\n");
