@@ -46,6 +46,11 @@
 #include "nsCRT.h"
 #include "nsCOMPtr.h"
 #include "prlink.h"
+
+#include "nsIPlugin.h"
+#include "nsIPluginTagInfo2.h"
+#include "nsIPluginInstancePeer2.h"
+
 #include "nsIFileUtilities.h"
 #include "nsICookieStorage.h"
 #include "nsPluginsDir.h"
@@ -53,6 +58,9 @@
 #include "nsIDirectoryService.h"
 #include "nsWeakPtr.h"
 #include "nsIPrompt.h"
+#include "nsIGenericFactory.h"
+#include "nsISupportsArray.h"
+#include "nsPluginNativeWindow.h"
 
 class ns4xPlugin;
 class nsFileSpec;
@@ -60,6 +68,7 @@ class nsIComponentManager;
 class nsIFile;
 class nsIChannel;
 class nsIRegistry;
+class nsPluginHostImpl;
 
 /**
  * A linked-list of plugin information that is used for
@@ -86,11 +95,13 @@ public:
 
   ~nsPluginTag();
 
+  void SetHost(nsPluginHostImpl * aHost);
   void TryUnloadPlugin(PRBool aForceShutdown = PR_FALSE);
   void Mark(PRUint32 mask) { mFlags |= mask; }
   PRBool Equals(nsPluginTag* aPluginTag);
 
   nsPluginTag   *mNext;
+  nsPluginHostImpl *mPluginHost;
   char          *mName;
   char          *mDescription;
   PRInt32       mVariants;
@@ -118,12 +129,14 @@ struct nsActivePlugin
   PRTime                 mllStopTime;
   PRBool                 mDefaultPlugin;
   PRBool                 mXPConnected;
-  nsVoidArray*           mStreams;
+  //Array holding all opened stream listeners for this entry
+  nsCOMPtr <nsISupportsArray>  mStreams; 
 
   nsActivePlugin(nsPluginTag* aPluginTag,
                  nsIPluginInstance* aInstance, 
                  const char * url,
-                 PRBool aDefaultPlugin);
+                 PRBool aDefaultPlugin,
+                 nsIPluginInstancePeer *peer);
   ~nsActivePlugin();
 
   void setStopped(PRBool stopped);
@@ -141,33 +154,17 @@ public:
 
   void shut();
   PRBool add(nsActivePlugin * plugin);
-  PRBool remove(nsActivePlugin * plugin, PRBool * aUnloadLibraryLater);
+  PRBool remove(nsActivePlugin * plugin);
   nsActivePlugin * find(nsIPluginInstance* instance);
   nsActivePlugin * find(const char * mimetype);
   nsActivePlugin * findStopped(const char * url);
   PRUint32 getStoppedCount();
   nsActivePlugin * findOldestStopped();
   void removeAllStopped();
-  void stopRunning();
+  void stopRunning(nsISupportsArray* aReloadDocs);
   PRBool IsLastInstance(nsActivePlugin * plugin);
 };
 
-// The purpose of this list is to keep track of unloaded plugin libs
-// we need to keep some libs in memory when we destroy mPlugins list
-// during refresh with reload if the plugin is currently running
-// on the page. They should be unloaded later, see bug #61388
-// There could also be other reasons to have this list. XPConnected
-// plugins e.g. may still be held at the time we normally unload the library
-class nsUnusedLibrary
-{
-public:
-  nsUnusedLibrary *mNext;
-  PRLibrary *mLibrary;
-
-  nsUnusedLibrary(PRLibrary * aLibrary);
-  ~nsUnusedLibrary();
-};
-
 #define NS_PLUGIN_FLAG_ENABLED    0x0001    //is this plugin enabled?
 #define NS_PLUGIN_FLAG_OLDSCHOOL  0x0002    //is this a pre-xpcom plugin?
 #define NS_PLUGIN_FLAG_FROMCACHE  0x0004    // this plugintag info was loaded from cache
@@ -363,7 +360,7 @@ public:
 
   // Methods from nsPIPluginHost
   NS_IMETHOD
-  SetIsScriptableInstance(nsCOMPtr<nsIPluginInstance> aPluginInstance, PRBool aScriptable);
+  SetIsScriptableInstance(nsIPluginInstance *aPluginInstance, PRBool aScriptable);
 
   NS_IMETHOD
   ParsePostBufferToFixHeaders(const char *inPostData, PRUint32 inPostDataLen, 
@@ -372,6 +369,12 @@ public:
   NS_IMETHOD
   CreateTmpFileToPost(const char *postDataURL, char **pTmpFileName);
 
+  NS_IMETHOD
+  NewPluginNativeWindow(nsPluginNativeWindow ** aPluginNativeWindow);
+
+  NS_IMETHOD
+  DeletePluginNativeWindow(nsPluginNativeWindow * aPluginNativeWindow);
+
   /* Called by GetURL and PostURL */
 
   NS_IMETHOD
@@ -391,12 +394,15 @@ public:
   NS_IMETHOD
   StopPluginInstance(nsIPluginInstance* aInstance);
 
+  NS_IMETHOD
+  AddUnusedLibrary(PRLibrary * aLibrary);
+
 private:
   NS_IMETHOD
   TrySetUpPluginInstance(const char *aMimeType, nsIURI *aURL, nsIPluginInstanceOwner *aOwner);
 
   nsresult
-  LoadXPCOMPlugins(nsIComponentManager* aComponentManager, nsIFile* aPath);
+  LoadXPCOMPlugins(nsIComponentManager* aComponentManager);
 
   nsresult
   NewEmbededPluginStream(nsIURI* aURL, nsIPluginInstanceOwner *aOwner, nsIPluginInstance* aInstance);
@@ -413,13 +419,14 @@ private:
   nsresult
   SetUpDefaultPluginInstance(const char *aMimeType, nsIURI *aURL, nsIPluginInstanceOwner *aOwner);
 
-  void
+  nsresult
   AddInstanceToActiveList(nsCOMPtr<nsIPlugin> aPlugin,
                           nsIPluginInstance* aInstance,
-                          nsIURI* aURL, PRBool aDefaultPlugin);
+                          nsIURI* aURL, PRBool aDefaultPlugin,
+                          nsIPluginInstancePeer *peer);
 
   nsresult 
-  RegisterPluginMimeTypesWithLayout(nsPluginTag *pluginTag, nsIComponentManager * compManager, nsIFile * layoutPath);
+  RegisterPluginMimeTypesWithLayout(nsPluginTag *pluginTag, nsIComponentManager * compManager);
 
   nsresult
   FindPlugins(PRBool aCreatePluginList, PRBool * aPluginsChanged);
@@ -427,7 +434,6 @@ private:
   nsresult
   ScanPluginsDirectory(nsIFile * pluginsDir, 
                        nsIComponentManager * compManager, 
-                       nsIFile * layoutPath,
                        PRBool aCreatePluginList,
                        PRBool * aPluginsChanged,
                        PRBool checkForUnwantedPlugins = PR_FALSE);
@@ -435,20 +441,17 @@ private:
   nsresult
   ScanPluginsDirectoryList(nsISimpleEnumerator * dirEnum,
                            nsIComponentManager * compManager, 
-                           nsIFile * layoutPath,
                            PRBool aCreatePluginList,
                            PRBool * aPluginsChanged,
                            PRBool checkForUnwantedPlugins = PR_FALSE);
 
   PRBool IsRunningPlugin(nsPluginTag * plugin);
-  void AddToUnusedLibraryList(PRLibrary * aLibrary);
-  void CleanUnusedLibraries();
-
-  // Loads all cached plugins info into mCachedPlugins
-  nsresult LoadCachedPluginsInfo(nsIRegistry* registry);
 
   // Stores all plugins info into the registry
-  nsresult CachePluginsInfo(nsIRegistry* registry);
+  nsresult WritePluginInfo();
+
+  // Loads all cached plugins info into mCachedPlugins
+  nsresult ReadPluginInfo();
 
   // Given a filename, returns the plugins info from our cache
   // and removes it from the cache.
@@ -469,7 +472,7 @@ private:
   nsresult GetPrompt(nsIPluginInstanceOwner *aOwner, nsIPrompt **aPrompt);
 
   // one-off hack to include nppl3260.dll from the components folder
-  nsresult ScanForRealInComponentsFolder(nsIComponentManager * aCompManager, nsIFile * aLayoutPath);
+  nsresult ScanForRealInComponentsFolder(nsIComponentManager * aCompManager);
 
   char        *mPluginPath;
   nsPluginTag *mPlugins;
@@ -481,10 +484,13 @@ private:
   PRBool      mAllowAlienStarHandler;  // set by pref plugin.allow_alien_star_handler
 
   nsActivePluginList mActivePluginList;
-  nsUnusedLibrary *mUnusedLibraries;
+  nsVoidArray mUnusedLibraries;
 
+  nsCOMPtr<nsIFile> mPluginsDir;
   nsCOMPtr<nsIDirectoryServiceProvider> mPrivateDirServiceProvider;  
   nsWeakPtr mCurrentDocument; // weak reference, we use it to id document only
+
+  nsCOMPtr<nsIGenericFactory> mFactory;
 };
 
 #endif
