@@ -115,7 +115,7 @@ public:
     PRUint32 GetBytesTransfered() {return mBytesTransfered;} ;
     void Uploading(PRBool value);
     void SetRetrying(PRBool retry);
-
+    
 protected:
 
     nsCOMPtr<nsIRequest>              mRequest;
@@ -129,7 +129,7 @@ protected:
     PRPackedBool   mDelayedOnStartFired;
     PRPackedBool   mUploading;
     PRPackedBool   mRetrying;
-    
+
     nsresult DelayedOnStartRequest(nsIRequest *request, nsISupports *ctxt);
 };
 
@@ -152,7 +152,7 @@ NS_IMPL_THREADSAFE_ISUPPORTS8(DataRequestForwarder,
 DataRequestForwarder::DataRequestForwarder()
 {
     PR_LOG(gFTPLog, PR_LOG_DEBUG, ("(%x) DataRequestForwarder CREATED\n", this));
-        
+
     mBytesTransfered = 0;
     mRetrying = mUploading = mDelayedOnStartFired = PR_FALSE;
     NS_INIT_ISUPPORTS();
@@ -406,7 +406,7 @@ nsFtpState::nsFtpState() {
     // bool init
     mRETRFailed = PR_FALSE;
     mWaitingForDConn = mTryingCachedControl = mRetryPass = PR_FALSE;
-    mFireCallbacks = mKeepRunning = mAnonymous = PR_TRUE;
+    mKeepRunning = mAnonymous = PR_TRUE;
 
     mAction = GET;
     mState = FTP_COMMAND_CONNECT;
@@ -466,36 +466,56 @@ nsFtpState::OnDataAvailable(nsIRequest *request,
     }
 
     char* buffer = (char*)nsMemory::Alloc(aCount + 1);
+    if (!buffer)
+        return NS_ERROR_OUT_OF_MEMORY;
     nsresult rv = aInStream->Read(buffer, aCount, &aCount);
     if (NS_FAILED(rv)) 
     {
         PR_LOG(gFTPLog, PR_LOG_DEBUG, ("(%x) nsFtpState - error reading %x\n", this, rv));
+        nsMemory::Free(buffer);
         return NS_ERROR_FAILURE;
     }
     buffer[aCount] = '\0';
-        
+    
+    nsXPIDLCString data;
+    data.Adopt(buffer);
 
     PR_LOG(gFTPLog, PR_LOG_DEBUG, ("(%x) reading %d bytes: \"%s\"", this, aCount, buffer));
 
     // Sometimes we can get two responses in the same packet, eg from LIST.
     // So we need to parse the response line by line
     nsCString lines(mControlReadCarryOverBuf);
-    lines.Append(buffer, aCount);
+    lines.Append(data, aCount);
     // Clear the carryover buf - if we still don't have a line, then it will
     // be reappended below
     mControlReadCarryOverBuf.Truncate();
 
     const char* currLine = lines.get();
     while (*currLine) {
-        const char* eol = strstr(currLine, CRLF);
-        if (!eol) {
-            mControlReadCarryOverBuf.Assign(currLine);
-            break;
-        }
+       PRInt32 eolLength = strcspn(currLine, CRLF);
 
-        // Append the current segment, including the CRLF
+       if (eolLength == 0 && currLine[0] == '\0')
+           break;
+
+       PRInt32 currLineLength = strlen(currLine);
+
+       if (eolLength == currLineLength) {
+           mControlReadCarryOverBuf.Assign(currLine);
+           break;
+       }
+
+        // Append the current segment, including the LF
         nsCAutoString line;
-        line.Assign(currLine, eol - currLine + 2);
+        PRInt32 crlfLength = 0;
+
+        if ((currLineLength > eolLength) &&
+            (currLine[eolLength] == nsCRT::CR) &&
+            (currLine[eolLength+1] == nsCRT::LF))
+            crlfLength = 2; // CR +LF 
+        else 
+            crlfLength = 1; // + LF or CR
+
+        line.Assign(currLine, eolLength + crlfLength);
         
         // Does this start with a response code?
         PRBool startNum = (line.Length() >= 3 &&
@@ -534,7 +554,7 @@ nsFtpState::OnDataAvailable(nsIRequest *request,
             if (NS_FAILED(rv)) return rv;
         }
 
-        currLine = eol+2; // CR+LF
+        currLine = currLine + eolLength + crlfLength;
     }
 
     return NS_OK;
@@ -683,8 +703,10 @@ nsFtpState::Process()
               break;
           
           case FTP_ERROR: // xx needs more work to handle dropped control connection cases
-              if (mTryingCachedControl && mResponseCode == 530 &&
-                  mInternalError == NS_ERROR_FTP_PASV) {
+              if ((mTryingCachedControl && mResponseCode == 530 &&
+                  mInternalError == NS_ERROR_FTP_PASV) ||
+                  (mResponseCode == 425 &&
+                  mInternalError == NS_ERROR_FTP_PASV)) {
                   // The user was logged out during an pasv operation
                   // we want to restart this request with a new control
                   // channel.
@@ -973,8 +995,8 @@ return rv;
 ///////////////////////////////////
 nsresult
 nsFtpState::S_user() {
-    // some servers on connect send us a 421.  (84525)
-    if (mResponseCode == 421)
+    // some servers on connect send us a 421 or 521.  (84525) (141784)
+    if ((mResponseCode == 421) || (mResponseCode == 521))
         return NS_ERROR_FAILURE;
 
     nsresult rv;
@@ -1108,9 +1130,11 @@ nsFtpState::S_pass() {
                                                nsIAuthPrompt::SAVE_PASSWORD_PERMANENTLY,
                                                &passwd, &retval);
 
-            // we want to fail if the user canceled or didn't enter a password.
-            if (!retval || (passwd && !*passwd) )
+            // we want to fail if the user canceled. Note here that if they want
+            // a blank password, we will pass it along.
+            if (!retval)
                 return NS_ERROR_FAILURE;
+
             mPassword = passwd;
         }
         // XXX mPassword may contain non-ASCII characters!  what do we do?
@@ -1247,7 +1271,6 @@ nsFtpState::R_syst() {
             // since we just alerted the user, clear mResponseMsg,
             // which is displayed to the user.
             mResponseMsg = "";
-            
             return FTP_ERROR;
         }
         
@@ -1425,9 +1448,6 @@ nsFtpState::SetContentType()
     switch (mListFormat) {
     case nsIDirectoryListing::FORMAT_RAW:
         {
-            nsAutoString fromStr(NS_LITERAL_STRING("text/ftp-dir-"));
-            SetDirMIMEType(fromStr);
-
             contentType = NS_LITERAL_CSTRING("text/ftp-dir-");
         }
         break;
@@ -1513,8 +1533,6 @@ nsFtpState::R_list() {
         mNextState = FTP_COMPLETE;
         return FTP_COMPLETE;
     }
-
-    mFireCallbacks = PR_TRUE;
     return FTP_ERROR;
 }
 
@@ -1942,14 +1960,8 @@ nsFtpState::Cancel(nsresult status)
     if (NS_SUCCEEDED(mControlStatus))
         mControlStatus = status;
 
-    // kill the data connection immediately. 
-    NS_IF_RELEASE(mDRequestForwarder);
-    if (mDPipeRequest) {
-        mDPipeRequest->Cancel(status);
-        mDPipeRequest = 0;
-    }
-
-    (void) StopProcessing();   
+    if (mKeepRunning)
+        (void) StopProcessing();   
     return NS_OK;
 }
 
@@ -2369,15 +2381,30 @@ nsFtpState::StopProcessing() {
     if ( NS_SUCCEEDED(broadcastErrorCode))
         broadcastErrorCode = mInternalError;
 
-    if (mFireCallbacks && mChannel) {
-        nsCOMPtr<nsIStreamListener> channelListener = do_QueryInterface(mChannel);
-        NS_ASSERTION(channelListener, "ftp channel should be a stream listener");
-        nsCOMPtr<nsIStreamListener> asyncListener;
-        NS_NewAsyncStreamListener(getter_AddRefs(asyncListener), channelListener, NS_UI_THREAD_EVENTQ);
-        if(asyncListener) {
-            (void) asyncListener->OnStartRequest(this, nsnull);
-            (void) asyncListener->OnStopRequest(this, nsnull, broadcastErrorCode);
+    mInternalError = broadcastErrorCode;
+
+    if (mDPipeRequest && NS_FAILED(broadcastErrorCode))
+        mDPipeRequest->Cancel(broadcastErrorCode);
+    
+    if (mDRequestForwarder) {
+        NS_RELEASE(mDRequestForwarder);
+    }
+    else
+    {
+        // The forwarding object was never created which  means that we never sent our notifications.
+        
+        nsCOMPtr<nsIRequestObserver> asyncObserver = do_QueryInterface(mChannel);
+        nsCOMPtr<nsIRequestObserver> arg = do_QueryInterface(mChannel);
+
+        NS_NewRequestObserverProxy(getter_AddRefs(asyncObserver), 
+                                   arg,
+                                   NS_CURRENT_EVENTQ);
+        if(asyncObserver) {
+            (void) asyncObserver->OnStartRequest(this, nsnull);
+            (void) asyncObserver->OnStopRequest(this, nsnull, broadcastErrorCode);
         }
+
+
     }
 
     // Clean up the event loop
@@ -2400,27 +2427,6 @@ nsFtpState::StopProcessing() {
     return NS_OK;
 }
 
-void
-nsFtpState::SetDirMIMEType(nsString& aString) {
-    // the from content type is a string of the form
-    // "text/ftp-dir-SERVER_TYPE" where SERVER_TYPE represents the server we're talking to.
-    switch (mServerType) {
-    case FTP_UNIX_TYPE:
-        aString.Append(NS_LITERAL_STRING("unix"));
-        break;
-    case FTP_NT_TYPE:
-        aString.Append(NS_LITERAL_STRING("nt"));
-        break;
-    case FTP_OS2_TYPE:
-        aString.Append(NS_LITERAL_STRING("os2"));
-        break;
-    case FTP_VMS_TYPE:
-        aString.Append(NS_LITERAL_STRING("vms"));
-        break;
-    default:
-        aString.Append(NS_LITERAL_STRING("generic"));
-    }
-}
 
 nsresult
 nsFtpState::BuildStreamConverter(nsIStreamListener** convertStreamListener)
@@ -2438,8 +2444,8 @@ nsFtpState::BuildStreamConverter(nsIStreamListener** convertStreamListener)
     if (NS_FAILED(rv)) 
         return rv;
 
-    nsAutoString fromStr(NS_LITERAL_STRING("text/ftp-dir-"));
-    SetDirMIMEType(fromStr);
+    nsAutoString fromStr(NS_LITERAL_STRING("text/ftp-dir"));
+    
     switch (mListFormat) {
     case nsIDirectoryListing::FORMAT_RAW:
         converterListener = listener;
@@ -2488,7 +2494,6 @@ nsFtpState::DataConnectionEstablished()
 {
     PR_LOG(gFTPLog, PR_LOG_DEBUG, ("(%x) Data Connection established.", this));
     
-    mFireCallbacks  = PR_FALSE; // observer callbacks will be handled by the transport.
     mWaitingForDConn= PR_FALSE;
 
     // sending empty string with (mWaitingForDConn == PR_FALSE) will cause the 
