@@ -46,9 +46,10 @@
 #include "netCore.h"
 #include "nsXPIDLString.h"
 #include "nsIPref.h"
-#include "nsReadableUtils.h"
 #include "imgILoader.h"
 
+#include "nsIViewSourceChannel.h"
+
 #include "prcpucfg.h" // To get IS_LITTLE_ENDIAN / IS_BIG_ENDIAN
 
 #define MAX_BUFFER_SIZE 1024
@@ -68,7 +69,6 @@ nsUnknownDecoder::nsUnknownDecoder()
   mBuffer = nsnull;
   mBufferLen = 0;
   mRequireHTMLsuffix = PR_FALSE;
-  mViewingSource = PR_FALSE;
 
   nsresult rv;
   nsCOMPtr<nsIPref> pPrefService = do_GetService(kPrefServiceCID, &rv);
@@ -128,14 +128,6 @@ nsUnknownDecoder::AsyncConvertData(const PRUnichar *aFromType,
 {
   NS_ASSERTION(aListener && aFromType && aToType, 
                "null pointer passed into multi mixed converter");
-  nsDependentString fromType(aFromType);
-  nsAString::const_iterator start, end;
-  fromType.BeginReading(start);
-  fromType.EndReading(end);
-  if (FindInReadable(NS_LITERAL_STRING("; x-view-type=view-source"),
-                     start, end)) {
-    mViewingSource = PR_TRUE;
-  }
   // hook up our final listener. this guy gets the various On*() calls we want to throw
   // at him.
   //
@@ -423,15 +415,16 @@ nsresult nsUnknownDecoder::FireListenerNotifications(nsIRequest* request,
 
   if (!mBuffer) return NS_ERROR_OUT_OF_MEMORY;
 
-  nsCOMPtr<nsIChannel> channel = do_QueryInterface(request, &rv);
-  if (NS_FAILED(rv)) return rv;
-
-  if (mViewingSource) {
-    mContentType.Append(NS_LITERAL_CSTRING("; x-view-type=view-source"));
+  nsCOMPtr<nsIViewSourceChannel> viewSourceChannel = do_QueryInterface(request);
+  if (viewSourceChannel) {
+    rv = viewSourceChannel->SetOriginalContentType(mContentType);
+  } else {
+    nsCOMPtr<nsIChannel> channel = do_QueryInterface(request, &rv);
+    if (NS_FAILED(rv)) return rv;
+    
+    // Set the new content type on the channel...
+    rv = channel->SetContentType(mContentType);
   }
-  
-  // Set the new content type on the channel...
-  rv = channel->SetContentType(mContentType);
 
   NS_ASSERTION(NS_SUCCEEDED(rv), "Unable to set content type on channel!");
   if (NS_FAILED(rv))
