@@ -61,7 +61,7 @@
 
 */
 
-#include <new.h>
+#include NEW_H
 #include "nsCOMPtr.h"
 #include "nsIComponentManager.h"
 #include "nsIEnumerator.h"
@@ -186,7 +186,7 @@ CompositeEnumeratorImpl::CompositeEnumeratorImpl(CompositeDataSourceImpl* aCompo
       mAllowNegativeAssertions(aAllowNegativeAssertions),
       mCoalesceDuplicateArcs(aCoalesceDuplicateArcs)
 {
-	NS_INIT_REFCNT();
+	NS_INIT_ISUPPORTS();
 	NS_ADDREF(mCompositeDataSource);
 }
 
@@ -625,7 +625,7 @@ CompositeDataSourceImpl::CompositeDataSourceImpl(void)
 	  mCoalesceDuplicateArcs(PR_TRUE),
       mUpdateBatchNest(0)
 {
-    NS_INIT_REFCNT();
+    NS_INIT_ISUPPORTS();
 
     static const size_t kBucketSizes[] = {
         sizeof(CompositeAssertionEnumeratorImpl),
