@@ -93,6 +93,7 @@
 #include "nsReadableUtils.h"
 #include "nsIExpatSink.h"
 #include "nsCRT.h"
+#include "nsIAtom.h"
 
 ////////////////////////////////////////////////////////////////////////
 
@@ -325,7 +326,7 @@ RDFContentSinkImpl::RDFContentSinkImpl()
       mContextStack(nsnull),
       mDocumentURL(nsnull)
 {
-    NS_INIT_REFCNT();
+    NS_INIT_ISUPPORTS();
 
     if (gRefCnt++ == 0) {
         nsresult rv;
@@ -624,6 +625,13 @@ RDFContentSinkImpl::HandleProcessingInstruction(const PRUnichar *aTarget,
     return NS_OK;
 }
 
+NS_IMETHODIMP 
+RDFContentSinkImpl::HandleXMLDeclaration(const PRUnichar *aData, 
+                                         PRUint32 aLength)
+{
+    return NS_OK;
+}
+
 NS_IMETHODIMP
 RDFContentSinkImpl::ReportError(const PRUnichar* aErrorText, 
                                 const PRUnichar* aSourceText)
