@@ -32,7 +32,7 @@
  */
 
 #ifdef DEBUG
-static const char CVS_ID[] = "@(#) $RCSfile: devslot.c,v $ $Revision: 1.7.2.1 $ $Date: 2002/06/14 18:42:41 $ $Name: MOZILLA_1_1_RELEASE $";
+static const char CVS_ID[] = "@(#) $RCSfile: devslot.c,v $ $Revision: 1.12 $ $Date: 2002/09/06 00:27:37 $ $Name: MOZILLA_1_2_RELEASE $";
 #endif /* DEBUG */
 
 #ifndef NSSCKEPV_H
@@ -48,7 +48,7 @@ static const char CVS_ID[] = "@(#) $RCSfile: devslot.c,v $ $Revision: 1.7.2.1 $
 #endif /* CKHELPER_H */
 
 /* measured in seconds */
-#define NSSSLOT_TOKEN_DELAY_TIME 10
+#define NSSSLOT_TOKEN_DELAY_TIME 1
 
 /* this should track global and per-transaction login information */
 
@@ -91,6 +91,7 @@ static PRIntervalTime s_token_delay_time = 0;
 /* The flags needed to open a read-only session. */
 static const CK_FLAGS s_ck_readonly_flags = CKF_SERIAL_SESSION;
 
+#ifdef PURE_STAN_BUILD
 /* In pk11slot.c, this was a no-op.  So it is here also. */
 static CK_RV PR_CALLBACK
 nss_ck_slot_notify
@@ -103,7 +104,6 @@ nss_ck_slot_notify
     return CKR_OK;
 }
 
-#ifdef PURE_STAN_BUILD
 NSS_IMPLEMENT NSSSlot *
 nssSlot_Create
 (
@@ -237,7 +237,8 @@ within_token_delay_period(NSSSlot *slot)
     }
     time = PR_IntervalNow();
     lastTime = slot->lastTokenPing;
-    if ((time > lastTime) && ((time - lastTime) < s_token_delay_time)) {
+    if ((lastTime) &&
+	(time > lastTime) && ((time - lastTime) < s_token_delay_time)) {
 	return PR_TRUE;
     }
     slot->lastTokenPing = time;
@@ -298,7 +299,7 @@ nssSlot_IsTokenPresent
 	if (slot->token->base.name[0] != 0) {
 	    /* notify the high-level cache that the token is removed */
 	    slot->token->base.name[0] = 0; /* XXX */
-	    nssToken_NofifyCertsNotVisible(slot->token);
+	    nssToken_NotifyCertsNotVisible(slot->token);
 	}
 #endif
 	slot->token->base.name[0] = 0; /* XXX */
@@ -334,7 +335,7 @@ nssSlot_IsTokenPresent
 	/* the token has been removed, and reinserted, invalidate all the old
 	 * information we had on this token */
 #ifdef NSS_3_4_CODE
-	nssToken_NofifyCertsNotVisible(slot->token);
+	nssToken_NotifyCertsNotVisible(slot->token);
 #endif /* NSS_3_4_CODE */
 	nssToken_Remove(slot->token);
 	/* token has been removed, need to refresh with new session */
