@@ -32,7 +32,7 @@
  */
 
 #ifdef DEBUG
-static const char CVS_ID[] = "@(#) $RCSfile: dev3hack.c,v $ $Revision: 1.15 $ $Date: 2002/04/25 00:25:58 $ $Name: MOZILLA_1_1_RELEASE $";
+static const char CVS_ID[] = "@(#) $RCSfile: dev3hack.c,v $ $Revision: 1.17 $ $Date: 2002/05/30 02:08:07 $ $Name: MOZILLA_1_2_RELEASE $";
 #endif /* DEBUG */
 
 #ifndef NSS_3_4_CODE
@@ -284,7 +284,7 @@ nssTrustDomain_RemoveTokenCertsFromCache
 );
 
 NSS_IMPLEMENT PRStatus
-nssToken_NofifyCertsNotVisible
+nssToken_NotifyCertsNotVisible
 (
   NSSToken *tok
 )
