@@ -32,7 +32,7 @@
  */
 
 #ifdef DEBUG
-static const char CVS_ID[] = "@(#) $RCSfile: cryptocontext.c,v $ $Revision: 1.10 $ $Date: 2002/04/15 15:22:08 $ $Name: MOZILLA_1_1_RELEASE $";
+static const char CVS_ID[] = "@(#) $RCSfile: cryptocontext.c,v $ $Revision: 1.11 $ $Date: 2002/09/23 21:32:31 $ $Name: MOZILLA_1_2_RELEASE $";
 #endif /* DEBUG */
 
 #ifndef DEV_H
@@ -64,8 +64,7 @@ struct NSSCryptoContextStr
 extern const NSSError NSS_ERROR_NOT_FOUND;
 
 NSS_IMPLEMENT NSSCryptoContext *
-nssCryptoContext_Create
-(
+nssCryptoContext_Create (
   NSSTrustDomain *td,
   NSSCallback *uhhOpt
 )
@@ -86,8 +85,7 @@ nssCryptoContext_Create
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_Destroy
-(
+NSSCryptoContext_Destroy (
   NSSCryptoContext *cc
 )
 {
@@ -99,8 +97,7 @@ NSSCryptoContext_Destroy
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_SetDefaultCallback
-(
+NSSCryptoContext_SetDefaultCallback (
   NSSCryptoContext *td,
   NSSCallback *newCallback,
   NSSCallback **oldCallbackOpt
@@ -111,8 +108,7 @@ NSSCryptoContext_SetDefaultCallback
 }
 
 NSS_IMPLEMENT NSSCallback *
-NSSCryptoContext_GetDefaultCallback
-(
+NSSCryptoContext_GetDefaultCallback (
   NSSCryptoContext *td,
   PRStatus *statusOpt
 )
@@ -122,8 +118,7 @@ NSSCryptoContext_GetDefaultCallback
 }
 
 NSS_IMPLEMENT NSSTrustDomain *
-NSSCryptoContext_GetTrustDomain
-(
+NSSCryptoContext_GetTrustDomain (
   NSSCryptoContext *td
 )
 {
@@ -132,8 +127,7 @@ NSSCryptoContext_GetTrustDomain
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_ImportCertificate
-(
+NSSCryptoContext_ImportCertificate (
   NSSCryptoContext *cc,
   NSSCertificate *c
 )
@@ -153,8 +147,7 @@ NSSCryptoContext_ImportCertificate
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_ImportPKIXCertificate
-(
+NSSCryptoContext_ImportPKIXCertificate (
   NSSCryptoContext *cc,
   struct NSSPKIXCertificateStr *pc
 )
@@ -164,8 +157,7 @@ NSSCryptoContext_ImportPKIXCertificate
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_ImportEncodedCertificate
-(
+NSSCryptoContext_ImportEncodedCertificate (
   NSSCryptoContext *cc,
   NSSBER *ber
 )
@@ -175,8 +167,7 @@ NSSCryptoContext_ImportEncodedCertificate
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_ImportEncodedPKIXCertificateChain
-(
+NSSCryptoContext_ImportEncodedPKIXCertificateChain (
   NSSCryptoContext *cc,
   NSSBER *ber
 )
@@ -186,8 +177,7 @@ NSSCryptoContext_ImportEncodedPKIXCertificateChain
 }
 
 NSS_IMPLEMENT PRStatus
-nssCryptoContext_ImportTrust
-(
+nssCryptoContext_ImportTrust (
   NSSCryptoContext *cc,
   NSSTrust *trust
 )
@@ -209,8 +199,7 @@ nssCryptoContext_ImportTrust
 }
 
 NSS_IMPLEMENT PRStatus
-nssCryptoContext_ImportSMIMEProfile
-(
+nssCryptoContext_ImportSMIMEProfile (
   NSSCryptoContext *cc,
   nssSMIMEProfile *profile
 )
@@ -232,8 +221,7 @@ nssCryptoContext_ImportSMIMEProfile
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_FindBestCertificateByNickname
-(
+NSSCryptoContext_FindBestCertificateByNickname (
   NSSCryptoContext *cc,
   NSSUTF8 *name,
   NSSTime *timeOpt, /* NULL for "now" */
@@ -260,8 +248,7 @@ NSSCryptoContext_FindBestCertificateByNickname
 }
 
 NSS_IMPLEMENT NSSCertificate **
-NSSCryptoContext_FindCertificatesByNickname
-(
+NSSCryptoContext_FindCertificatesByNickname (
   NSSCryptoContext *cc,
   NSSUTF8 *name,
   NSSCertificate *rvOpt[],
@@ -282,8 +269,7 @@ NSSCryptoContext_FindCertificatesByNickname
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_FindCertificateByIssuerAndSerialNumber
-(
+NSSCryptoContext_FindCertificateByIssuerAndSerialNumber (
   NSSCryptoContext *cc,
   NSSDER *issuer,
   NSSDER *serialNumber
@@ -299,8 +285,7 @@ NSSCryptoContext_FindCertificateByIssuerAndSerialNumber
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_FindBestCertificateBySubject
-(
+NSSCryptoContext_FindBestCertificateBySubject (
   NSSCryptoContext *cc,
   NSSDER *subject,
   NSSTime *timeOpt,
@@ -327,8 +312,7 @@ NSSCryptoContext_FindBestCertificateBySubject
 }
 
 NSS_IMPLEMENT NSSCertificate **
-nssCryptoContext_FindCertificatesBySubject
-(
+nssCryptoContext_FindCertificatesBySubject (
   NSSCryptoContext *cc,
   NSSDER *subject,
   NSSCertificate *rvOpt[],
@@ -349,8 +333,7 @@ nssCryptoContext_FindCertificatesBySubject
 }
 
 NSS_IMPLEMENT NSSCertificate **
-NSSCryptoContext_FindCertificatesBySubject
-(
+NSSCryptoContext_FindCertificatesBySubject (
   NSSCryptoContext *cc,
   NSSDER *subject,
   NSSCertificate *rvOpt[],
@@ -364,8 +347,7 @@ NSSCryptoContext_FindCertificatesBySubject
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_FindBestCertificateByNameComponents
-(
+NSSCryptoContext_FindBestCertificateByNameComponents (
   NSSCryptoContext *cc,
   NSSUTF8 *nameComponents,
   NSSTime *timeOpt,
@@ -378,8 +360,7 @@ NSSCryptoContext_FindBestCertificateByNameComponents
 }
 
 NSS_IMPLEMENT NSSCertificate **
-NSSCryptoContext_FindCertificatesByNameComponents
-(
+NSSCryptoContext_FindCertificatesByNameComponents (
   NSSCryptoContext *cc,
   NSSUTF8 *nameComponents,
   NSSCertificate *rvOpt[],
@@ -392,8 +373,7 @@ NSSCryptoContext_FindCertificatesByNameComponents
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_FindCertificateByEncodedCertificate
-(
+NSSCryptoContext_FindCertificateByEncodedCertificate (
   NSSCryptoContext *cc,
   NSSBER *encodedCertificate
 )
@@ -407,8 +387,7 @@ NSSCryptoContext_FindCertificateByEncodedCertificate
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_FindBestCertificateByEmail
-(
+NSSCryptoContext_FindBestCertificateByEmail (
   NSSCryptoContext *cc,
   NSSASCII7 *email,
   NSSTime *timeOpt,
@@ -435,8 +414,7 @@ NSSCryptoContext_FindBestCertificateByEmail
 }
 
 NSS_IMPLEMENT NSSCertificate **
-NSSCryptoContext_FindCertificatesByEmail
-(
+NSSCryptoContext_FindCertificatesByEmail (
   NSSCryptoContext *cc,
   NSSASCII7 *email,
   NSSCertificate *rvOpt[],
@@ -457,8 +435,7 @@ NSSCryptoContext_FindCertificatesByEmail
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_FindCertificateByOCSPHash
-(
+NSSCryptoContext_FindCertificateByOCSPHash (
   NSSCryptoContext *cc,
   NSSItem *hash
 )
@@ -468,8 +445,7 @@ NSSCryptoContext_FindCertificateByOCSPHash
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_FindBestUserCertificate
-(
+NSSCryptoContext_FindBestUserCertificate (
   NSSCryptoContext *cc,
   NSSTime *timeOpt,
   NSSUsage *usage,
@@ -481,8 +457,7 @@ NSSCryptoContext_FindBestUserCertificate
 }
 
 NSS_IMPLEMENT NSSCertificate **
-NSSCryptoContext_FindUserCertificates
-(
+NSSCryptoContext_FindUserCertificates (
   NSSCryptoContext *cc,
   NSSTime *timeOpt,
   NSSUsage *usageOpt,
@@ -497,8 +472,7 @@ NSSCryptoContext_FindUserCertificates
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_FindBestUserCertificateForSSLClientAuth
-(
+NSSCryptoContext_FindBestUserCertificateForSSLClientAuth (
   NSSCryptoContext *cc,
   NSSUTF8 *sslHostOpt,
   NSSDER *rootCAsOpt[], /* null pointer for none */
@@ -512,8 +486,7 @@ NSSCryptoContext_FindBestUserCertificateForSSLClientAuth
 }
 
 NSS_IMPLEMENT NSSCertificate **
-NSSCryptoContext_FindUserCertificatesForSSLClientAuth
-(
+NSSCryptoContext_FindUserCertificatesForSSLClientAuth (
   NSSCryptoContext *cc,
   NSSUTF8 *sslHostOpt,
   NSSDER *rootCAsOpt[], /* null pointer for none */
@@ -530,8 +503,7 @@ NSSCryptoContext_FindUserCertificatesForSSLClientAuth
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_FindBestUserCertificateForEmailSigning
-(
+NSSCryptoContext_FindBestUserCertificateForEmailSigning (
   NSSCryptoContext *cc,
   NSSASCII7 *signerOpt,
   NSSASCII7 *recipientOpt,
@@ -545,8 +517,7 @@ NSSCryptoContext_FindBestUserCertificateForEmailSigning
 }
 
 NSS_IMPLEMENT NSSCertificate *
-NSSCryptoContext_FindUserCertificatesForEmailSigning
-(
+NSSCryptoContext_FindUserCertificatesForEmailSigning (
   NSSCryptoContext *cc,
   NSSASCII7 *signerOpt, /* fgmr or a more general name? */
   NSSASCII7 *recipientOpt,
@@ -563,8 +534,7 @@ NSSCryptoContext_FindUserCertificatesForEmailSigning
 }
 
 NSS_IMPLEMENT NSSTrust *
-nssCryptoContext_FindTrustForCertificate
-(
+nssCryptoContext_FindTrustForCertificate (
   NSSCryptoContext *cc,
   NSSCertificate *cert
 )
@@ -576,8 +546,7 @@ nssCryptoContext_FindTrustForCertificate
 }
 
 NSS_IMPLEMENT nssSMIMEProfile *
-nssCryptoContext_FindSMIMEProfileForCertificate
-(
+nssCryptoContext_FindSMIMEProfileForCertificate (
   NSSCryptoContext *cc,
   NSSCertificate *cert
 )
@@ -590,8 +559,7 @@ nssCryptoContext_FindSMIMEProfileForCertificate
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_GenerateKeyPair
-(
+NSSCryptoContext_GenerateKeyPair (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *ap,
   NSSPrivateKey **pvkOpt,
@@ -606,8 +574,7 @@ NSSCryptoContext_GenerateKeyPair
 }
 
 NSS_IMPLEMENT NSSSymmetricKey *
-NSSCryptoContext_GenerateSymmetricKey
-(
+NSSCryptoContext_GenerateSymmetricKey (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *ap,
   PRUint32 keysize,
@@ -620,8 +587,7 @@ NSSCryptoContext_GenerateSymmetricKey
 }
 
 NSS_IMPLEMENT NSSSymmetricKey *
-NSSCryptoContext_GenerateSymmetricKeyFromPassword
-(
+NSSCryptoContext_GenerateSymmetricKeyFromPassword (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *ap,
   NSSUTF8 *passwordOpt, /* if null, prompt */
@@ -634,8 +600,7 @@ NSSCryptoContext_GenerateSymmetricKeyFromPassword
 }
 
 NSS_IMPLEMENT NSSSymmetricKey *
-NSSCryptoContext_FindSymmetricKeyByAlgorithmAndKeyID
-(
+NSSCryptoContext_FindSymmetricKeyByAlgorithmAndKeyID (
   NSSCryptoContext *cc,
   NSSOID *algorithm,
   NSSItem *keyID,
@@ -652,8 +617,7 @@ struct token_session_str {
 };
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_Decrypt
-(
+NSSCryptoContext_Decrypt (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSItem *encryptedData,
@@ -667,8 +631,7 @@ NSSCryptoContext_Decrypt
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_BeginDecrypt
-(
+NSSCryptoContext_BeginDecrypt (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSCallback *uhhOpt
@@ -679,8 +642,7 @@ NSSCryptoContext_BeginDecrypt
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_ContinueDecrypt
-(
+NSSCryptoContext_ContinueDecrypt (
   NSSCryptoContext *cc,
   NSSItem *data,
   NSSItem *rvOpt,
@@ -692,8 +654,7 @@ NSSCryptoContext_ContinueDecrypt
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_FinishDecrypt
-(
+NSSCryptoContext_FinishDecrypt (
   NSSCryptoContext *cc,
   NSSItem *rvOpt,
   NSSArena *arenaOpt
@@ -704,8 +665,7 @@ NSSCryptoContext_FinishDecrypt
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_Sign
-(
+NSSCryptoContext_Sign (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSItem *data,
@@ -719,8 +679,7 @@ NSSCryptoContext_Sign
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_BeginSign
-(
+NSSCryptoContext_BeginSign (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSCallback *uhhOpt
@@ -731,8 +690,7 @@ NSSCryptoContext_BeginSign
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_ContinueSign
-(
+NSSCryptoContext_ContinueSign (
   NSSCryptoContext *cc,
   NSSItem *data
 )
@@ -742,8 +700,7 @@ NSSCryptoContext_ContinueSign
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_FinishSign
-(
+NSSCryptoContext_FinishSign (
   NSSCryptoContext *cc,
   NSSItem *rvOpt,
   NSSArena *arenaOpt
@@ -754,8 +711,7 @@ NSSCryptoContext_FinishSign
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_SignRecover
-(
+NSSCryptoContext_SignRecover (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSItem *data,
@@ -769,8 +725,7 @@ NSSCryptoContext_SignRecover
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_BeginSignRecover
-(
+NSSCryptoContext_BeginSignRecover (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSCallback *uhhOpt
@@ -781,8 +736,7 @@ NSSCryptoContext_BeginSignRecover
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_ContinueSignRecover
-(
+NSSCryptoContext_ContinueSignRecover (
   NSSCryptoContext *cc,
   NSSItem *data,
   NSSItem *rvOpt,
@@ -794,8 +748,7 @@ NSSCryptoContext_ContinueSignRecover
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_FinishSignRecover
-(
+NSSCryptoContext_FinishSignRecover (
   NSSCryptoContext *cc,
   NSSItem *rvOpt,
   NSSArena *arenaOpt
@@ -806,8 +759,7 @@ NSSCryptoContext_FinishSignRecover
 }
 
 NSS_IMPLEMENT NSSSymmetricKey *
-NSSCryptoContext_UnwrapSymmetricKey
-(
+NSSCryptoContext_UnwrapSymmetricKey (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSItem *wrappedKey,
@@ -819,8 +771,7 @@ NSSCryptoContext_UnwrapSymmetricKey
 }
 
 NSS_IMPLEMENT NSSSymmetricKey *
-NSSCryptoContext_DeriveSymmetricKey
-(
+NSSCryptoContext_DeriveSymmetricKey (
   NSSCryptoContext *cc,
   NSSPublicKey *bk,
   NSSAlgorithmAndParameters *apOpt,
@@ -835,8 +786,7 @@ NSSCryptoContext_DeriveSymmetricKey
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_Encrypt
-(
+NSSCryptoContext_Encrypt (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSItem *data,
@@ -850,8 +800,7 @@ NSSCryptoContext_Encrypt
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_BeginEncrypt
-(
+NSSCryptoContext_BeginEncrypt (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSCallback *uhhOpt
@@ -862,8 +811,7 @@ NSSCryptoContext_BeginEncrypt
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_ContinueEncrypt
-(
+NSSCryptoContext_ContinueEncrypt (
   NSSCryptoContext *cc,
   NSSItem *data,
   NSSItem *rvOpt,
@@ -875,8 +823,7 @@ NSSCryptoContext_ContinueEncrypt
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_FinishEncrypt
-(
+NSSCryptoContext_FinishEncrypt (
   NSSCryptoContext *cc,
   NSSItem *rvOpt,
   NSSArena *arenaOpt
@@ -887,8 +834,7 @@ NSSCryptoContext_FinishEncrypt
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_Verify
-(
+NSSCryptoContext_Verify (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSItem *data,
@@ -901,8 +847,7 @@ NSSCryptoContext_Verify
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_BeginVerify
-(
+NSSCryptoContext_BeginVerify (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSItem *signature,
@@ -914,8 +859,7 @@ NSSCryptoContext_BeginVerify
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_ContinueVerify
-(
+NSSCryptoContext_ContinueVerify (
   NSSCryptoContext *cc,
   NSSItem *data
 )
@@ -925,8 +869,7 @@ NSSCryptoContext_ContinueVerify
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_FinishVerify
-(
+NSSCryptoContext_FinishVerify (
   NSSCryptoContext *cc
 )
 {
@@ -935,8 +878,7 @@ NSSCryptoContext_FinishVerify
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_VerifyRecover
-(
+NSSCryptoContext_VerifyRecover (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSItem *signature,
@@ -950,8 +892,7 @@ NSSCryptoContext_VerifyRecover
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_BeginVerifyRecover
-(
+NSSCryptoContext_BeginVerifyRecover (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSCallback *uhhOpt
@@ -962,8 +903,7 @@ NSSCryptoContext_BeginVerifyRecover
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_ContinueVerifyRecover
-(
+NSSCryptoContext_ContinueVerifyRecover (
   NSSCryptoContext *cc,
   NSSItem *data,
   NSSItem *rvOpt,
@@ -975,8 +915,7 @@ NSSCryptoContext_ContinueVerifyRecover
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_FinishVerifyRecover
-(
+NSSCryptoContext_FinishVerifyRecover (
   NSSCryptoContext *cc,
   NSSItem *rvOpt,
   NSSArena *arenaOpt
@@ -987,8 +926,7 @@ NSSCryptoContext_FinishVerifyRecover
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_WrapSymmetricKey
-(
+NSSCryptoContext_WrapSymmetricKey (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSSymmetricKey *keyToWrap,
@@ -1002,8 +940,7 @@ NSSCryptoContext_WrapSymmetricKey
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_Digest
-(
+NSSCryptoContext_Digest (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSItem *data,
@@ -1017,8 +954,7 @@ NSSCryptoContext_Digest
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_BeginDigest
-(
+NSSCryptoContext_BeginDigest (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSCallback *uhhOpt
@@ -1028,8 +964,7 @@ NSSCryptoContext_BeginDigest
 }
 
 NSS_IMPLEMENT PRStatus
-NSSCryptoContext_ContinueDigest
-(
+NSSCryptoContext_ContinueDigest (
   NSSCryptoContext *cc,
   NSSAlgorithmAndParameters *apOpt,
   NSSItem *item
@@ -1044,8 +979,7 @@ NSSCryptoContext_ContinueDigest
 }
 
 NSS_IMPLEMENT NSSItem *
-NSSCryptoContext_FinishDigest
-(
+NSSCryptoContext_FinishDigest (
   NSSCryptoContext *cc,
   NSSItem *rvOpt,
   NSSArena *arenaOpt
@@ -1055,8 +989,7 @@ NSSCryptoContext_FinishDigest
 }
 
 NSS_IMPLEMENT NSSCryptoContext *
-NSSCryptoContext_Clone
-(
+NSSCryptoContext_Clone (
   NSSCryptoContext *cc
 )
 {
