@@ -33,7 +33,7 @@
 #include "prenv.h"
 #include "nsCRT.h"
 
-#if defined(XP_MAC) /* || defined(XP_MACOSX) REMIND HACKING FOR MACOS X!!! */
+#if defined(XP_MAC) || defined(XP_MACOSX)
 #include <Folders.h>
 #include <Script.h>
 #include <Processes.h>
@@ -60,7 +60,7 @@
 // WARNING: These hard coded names need to go away. They need to
 // come from localizable resources
 
-#if defined(XP_MAC) /* || defined(XP_MACOSX) REMIND HACKING FOR MACOS X!!! */
+#if defined(XP_MAC) || defined(XP_MACOSX)
 #define APP_REGISTRY_NAME NS_LITERAL_CSTRING("Application Registry")
 #define ESSENTIAL_FILES   NS_LITERAL_CSTRING("Essential Files")
 #elif defined(XP_WIN) || defined(XP_OS2)
@@ -70,7 +70,7 @@
 #endif
 
 // define default product directory
-#if defined(XP_WIN) || defined(XP_MAC) || defined(XP_OS2) || defined(XP_BEOS)
+#if defined(XP_WIN) || defined(XP_MAC) || defined(XP_MACOSX) || defined(XP_OS2) || defined(XP_BEOS)
 #define DEFAULT_PRODUCT_DIR NS_LITERAL_CSTRING("Mozilla")
 #elif defined (XP_UNIX)
 #define DEFAULT_PRODUCT_DIR NS_LITERAL_CSTRING(".mozilla")
@@ -80,7 +80,7 @@
 #define NS_ENV_PLUGINS_DIR          "EnvPlugins"    // env var MOZ_PLUGIN_PATH
 #define NS_USER_PLUGINS_DIR         "UserPlugins"
 
-#if defined(XP_MAC)
+#if defined(XP_MAC) || defined(XP_MACOSX)
 #define NS_MACOSX_USER_PLUGIN_DIR   "OSXUserPlugins"
 #define NS_MACOSX_LOCAL_PLUGIN_DIR  "OSXLocalPlugins"
 #define NS_MAC_CLASSIC_PLUGIN_DIR   "MacSysPlugins"
@@ -137,7 +137,7 @@ nsAppFileLocationProvider::GetFile(const char *prop, PRBool *persistant, nsIFile
     *_retval = nsnull;
     *persistant = PR_TRUE;
 
-#if defined (XP_MAC)
+#if defined (XP_MAC) || defined(XP_MACOSX)
     short foundVRefNum;
     long foundDirID;
     FSSpec fileSpec;
@@ -201,7 +201,7 @@ nsAppFileLocationProvider::GetFile(const char *prop, PRBool *persistant, nsIFile
         if (NS_SUCCEEDED(rv))
             rv = localFile->AppendRelativeNativePath(PLUGINS_DIR_NAME);
     }
-#if defined(XP_MAC)
+#if defined(XP_MAC) || defined(XP_MACOSX)
     else if (nsCRT::strcmp(prop, NS_MACOSX_USER_PLUGIN_DIR) == 0)
     {
         if (!(::FindFolder(kUserDomain,
@@ -238,6 +238,8 @@ nsAppFileLocationProvider::GetFile(const char *prop, PRBool *persistant, nsIFile
 #else
     else if (nsCRT::strcmp(prop, NS_ENV_PLUGINS_DIR) == 0)
     {
+        NS_ERROR("Don't use nsAppFileLocationProvider::GetFile(NS_ENV_PLUGINS_DIR, ...). "
+                 "Use nsAppFileLocationProvider::GetFiles(...).");
         const char *pathVar = PR_GetEnv("MOZ_PLUGIN_PATH");
         if (pathVar)
             rv = NS_NewNativeLocalFile(nsDependentCString(pathVar), PR_TRUE, getter_AddRefs(localFile));
@@ -327,7 +329,7 @@ NS_METHOD nsAppFileLocationProvider::GetProductDirectory(nsILocalFile **aLocalFi
     PRBool exists;
     nsCOMPtr<nsILocalFile> localDir;
 
-#if defined(XP_MAC) /* || defined(XP_MACOSX) REMIND HACKING FOR MACOS X!!! */
+#if defined(XP_MAC)
     nsCOMPtr<nsIProperties> directoryService = 
              do_GetService(NS_DIRECTORY_SERVICE_CONTRACTID, &rv);
     if (NS_FAILED(rv)) return rv;
@@ -336,7 +338,16 @@ NS_METHOD nsAppFileLocationProvider::GetProductDirectory(nsILocalFile **aLocalFi
     err = ::Gestalt(gestaltSystemVersion, &response);
     const char *prop = (!err && response >= 0x00001000) ? NS_MAC_USER_LIB_DIR : NS_MAC_DOCUMENTS_DIR;
     rv = directoryService->Get(prop, NS_GET_IID(nsILocalFile), getter_AddRefs(localDir));
-    if (NS_FAILED(rv)) return rv;   
+    if (NS_FAILED(rv)) return rv;
+#elif defined(XP_MACOSX)
+    FSRef fsRef;
+    OSErr err = ::FSFindFolder(kUserDomain, kDomainLibraryFolderType, kCreateFolder, &fsRef);
+    if (err) return NS_ERROR_FAILURE;
+    NS_NewLocalFile(nsString(), PR_TRUE, getter_AddRefs(localDir));
+    if (!localDir) return NS_ERROR_FAILURE;
+    nsCOMPtr<nsILocalFileMac> localDirMac(do_QueryInterface(localDir));
+    rv = localDirMac->InitWithFSRef(&fsRef);
+    if (NS_FAILED(rv)) return rv;
 #elif defined(XP_OS2)
     nsCOMPtr<nsIProperties> directoryService = 
              do_GetService(NS_DIRECTORY_SERVICE_CONTRACTID, &rv);
@@ -442,7 +453,7 @@ class nsAppDirectoryEnumerator : public nsISimpleEnumerator
         mProvider(aProvider),
         mCurrentKey(aKeyList)
     {
-        NS_INIT_REFCNT();
+        NS_INIT_ISUPPORTS();
     }
 
     NS_IMETHOD HasMoreElements(PRBool *result) 
@@ -450,7 +461,12 @@ class nsAppDirectoryEnumerator : public nsISimpleEnumerator
         while (!mNext && *mCurrentKey)
         {
             PRBool dontCare;
-            (void)mProvider->GetFile(*mCurrentKey++, &dontCare, getter_AddRefs(mNext));
+            nsCOMPtr<nsIFile> testFile;
+            (void)mProvider->GetFile(*mCurrentKey++, &dontCare, getter_AddRefs(testFile));
+            // Don't return a file which does not exist.
+            PRBool exists;
+            if (testFile && NS_SUCCEEDED(testFile->Exists(&exists)) && exists)
+                mNext = testFile;
         }
         *result = mNext != nsnull;
         return NS_OK;
@@ -485,6 +501,64 @@ class nsAppDirectoryEnumerator : public nsISimpleEnumerator
 
 NS_IMPL_ISUPPORTS1(nsAppDirectoryEnumerator, nsISimpleEnumerator)
 
+/* nsPathsDirectoryEnumerator and PATH_SEPARATOR
+ * are not used on MacOS/X. */
+
+#if defined(XP_WIN) || defined(XP_OS2)/* Win32, Win16, and OS/2 */
+#define PATH_SEPARATOR ';'
+#else /*if defined(XP_UNIX) || defined(XP_BEOS)*/
+#define PATH_SEPARATOR ':'
+#endif
+
+class nsPathsDirectoryEnumerator : public nsAppDirectoryEnumerator
+{
+  public:
+    /**
+     * aKeyList is a null-terminated list.
+     * The first element is a path list.
+     * The remainder are properties provided by aProvider.
+     * They do not need to be publicly defined keys.
+     */
+    nsPathsDirectoryEnumerator(nsIDirectoryServiceProvider *aProvider,
+                               const char* aKeyList[]) :
+    nsAppDirectoryEnumerator(aProvider, aKeyList+1),
+    mEndPath(aKeyList[0])
+    {
+    }
+
+    NS_IMETHOD HasMoreElements(PRBool *result) 
+    {
+        if (mEndPath)
+            while (!mNext && *mEndPath)
+            {
+                const char *pathVar = mEndPath;
+                do { ++mEndPath; } while (*mEndPath && *mEndPath != PATH_SEPARATOR);
+
+                nsCOMPtr<nsILocalFile> localFile;
+                NS_NewNativeLocalFile(Substring(pathVar, mEndPath),
+                                      PR_TRUE,
+                                      getter_AddRefs(localFile));
+                if (*mEndPath == PATH_SEPARATOR)
+                    ++mEndPath;
+                // Don't return a "file" (directory) which does not exist.
+                PRBool exists;
+                if (localFile &&
+                    NS_SUCCEEDED(localFile->Exists(&exists)) &&
+                    exists)
+                    mNext = localFile;
+            }
+        if (mNext)
+            *result = PR_TRUE;
+        else
+            nsAppDirectoryEnumerator::HasMoreElements(result);
+
+        return NS_OK;
+    }
+
+  protected:
+    const char *mEndPath;
+};
+
 NS_IMETHODIMP
 nsAppFileLocationProvider::GetFiles(const char *prop, nsISimpleEnumerator **_retval)
 {
@@ -494,7 +568,7 @@ nsAppFileLocationProvider::GetFiles(const char *prop, nsISimpleEnumerator **_ret
     
     if (!nsCRT::strcmp(prop, NS_APP_PLUGINS_DIR_LIST))
     {
-#ifdef XP_MAC
+#if defined(XP_MAC) || defined(XP_MACOSX)
         static const char* osXKeys[] = { NS_APP_PLUGINS_DIR, NS_MACOSX_USER_PLUGIN_DIR, NS_MACOSX_LOCAL_PLUGIN_DIR, nsnull };
         static const char* os9Keys[] = { NS_APP_PLUGINS_DIR, NS_MAC_CLASSIC_PLUGIN_DIR, nsnull };
         static const char** keys;
@@ -505,11 +579,16 @@ nsAppFileLocationProvider::GetFiles(const char *prop, nsISimpleEnumerator **_ret
             err = ::Gestalt(gestaltSystemVersion, &response); 
             keys = (!err && response >= 0x00001000) ? osXKeys : os9Keys;
         }
-#else
-        static const char* keys[] = { NS_ENV_PLUGINS_DIR, NS_USER_PLUGINS_DIR, NS_APP_PLUGINS_DIR, nsnull };
-#endif
 
         *_retval = new nsAppDirectoryEnumerator(this, keys);
+#else
+        static const char* keys[] = { nsnull, NS_USER_PLUGINS_DIR, NS_APP_PLUGINS_DIR, nsnull };
+        if (!keys[0] && !(keys[0] = PR_GetEnv("MOZ_PLUGIN_PATH"))) {
+            static const char nullstr = 0;
+            keys[0] = &nullstr;
+        }
+        *_retval = new nsPathsDirectoryEnumerator(this, keys);
+#endif
         NS_IF_ADDREF(*_retval);
         rv = *_retval ? NS_OK : NS_ERROR_OUT_OF_MEMORY;        
     }
