@@ -55,7 +55,6 @@
 #include "nsTopProgressNotifier.h"
 #include "nsLoggingProgressNotifier.h"
 
-#include "nsIRegistry.h"
 #include "nsBuildID.h"
 #include "nsSpecialSystemDirectory.h"
 #include "nsProcess.h"
@@ -86,8 +85,6 @@ static NS_DEFINE_CID(kInstallTrigger_CID, NS_SoftwareUpdateInstallTrigger_CID);
 
 static NS_DEFINE_CID(kInstallVersion_CID, NS_SoftwareUpdateInstallVersion_CID);
 
-static NS_DEFINE_CID(knsRegistryCID, NS_REGISTRY_CID);
-
 static NS_DEFINE_CID(kIProcessCID, NS_PROCESS_CID);
 
 nsSoftwareUpdate* nsSoftwareUpdate::mInstance = nsnull;
@@ -394,92 +391,6 @@ nsSoftwareUpdate::InstallJarCallBack()
 }
 
 
-NS_IMETHODIMP
-nsSoftwareUpdate::StartupTasks( PRBool *needAutoreg )
-{
-    PRBool  autoReg = PR_FALSE;
-    RKEY    xpiRoot;
-    REGERR  err;
-
-    *needAutoreg = PR_TRUE;
-
-    // First do any left-over file replacements and deletes
-
-    // NOTE: we leave the registry open until later to prevent
-    // having to load and unload it many times at startup
-
-    if ( REGERR_OK == NR_RegOpen("", &mReg) )
-    {
-        // XXX get a return val and if not all replaced autoreg again later
-        PerformScheduledTasks(mReg);
-
-        // now look for an autoreg flag left behind by XPInstall
-        err = NR_RegGetKey( mReg, ROOTKEY_COMMON, XPI_ROOT_KEY, &xpiRoot);
-        if ( err == REGERR_OK )
-        {
-            char buf[8];
-            err = NR_RegGetEntryString( mReg, xpiRoot, XPI_AUTOREG_VAL,
-                                        buf, sizeof(buf) );
-
-            if ( err == REGERR_OK && !strcmp( buf, "yes" ) )
-                autoReg = PR_TRUE;
-        }
-    }
-
-    // Also check for build number changes
-    nsresult rv;
-    PRInt32 buildID = -1;
-    nsRegistryKey idKey = 0;
-    nsCOMPtr<nsIRegistry> reg = do_GetService(knsRegistryCID,&rv);
-    if (NS_SUCCEEDED(rv))
-    {
-        rv = reg->OpenWellKnownRegistry(nsIRegistry::ApplicationComponentRegistry);
-        if (NS_SUCCEEDED(rv))
-        {
-            rv = reg->GetSubtree(nsIRegistry::Common,XPCOM_KEY,&idKey);
-            if (NS_SUCCEEDED(rv))
-            {
-                rv = reg->GetInt( idKey, XPI_AUTOREG_VAL, &buildID );
-            }
-        }
-    }
-
-    // Autoregister if we found the XPInstall flag, the stored BuildID
-    // is not the actual BuildID, or if we couldn't get the BuildID
-    if ( autoReg || NS_FAILED(rv) || buildID != NS_BUILD_ID )
-    {
-        nsCOMPtr<nsIServiceManager> servManager;
-        NS_GetServiceManager(getter_AddRefs(servManager));
-        nsCOMPtr<nsIComponentRegistrar> registrar = do_QueryInterface(servManager);
-        NS_ASSERTION(registrar, "No nsIComponentRegistrar from get service. see dougt");
-        rv = registrar->AutoRegister(nsnull);
-
-        if (NS_SUCCEEDED(rv))
-        {
-            *needAutoreg = PR_FALSE;
-
-            // Now store back into the registries so we don't do this again
-            if ( autoReg )
-                NR_RegSetEntryString( mReg, xpiRoot, XPI_AUTOREG_VAL, "no" );
-
-            if ( buildID != NS_BUILD_ID && idKey != 0 )
-                reg->SetInt( idKey, XPI_AUTOREG_VAL, NS_BUILD_ID );
-        }
-    }
-    else
-    {
-        //We don't need to autoreg, we're up to date
-        *needAutoreg = PR_FALSE;
-#ifdef DEBUG
-        // debug (developer) builds should always autoreg
-        *needAutoreg = PR_TRUE;
-#endif
-    }
-
-    return rv;
-}
-
-
 nsresult
 nsSoftwareUpdate::RunNextInstall()
 {
